/*
 * leds
 * Linux Editor for D 
 * S as in simple(superfluous) or supperb
 * 
 * by Antonio Monteiro
 */

module leds.FindAndReplace;

import dui.All;
import leds.Workspace;
import leds.Scintilla;

/**
 * A window to define the find and replace string and the modes.
 * The modes will be the Scintilla modes
 * - SCFIND_MATCHCASE
 * - SCFIND_WHOLEWORD
 * - SCFIND_WORDSTART
 * - SCFIND_REGEXP
 * - (not used) SCFIND_POSIX	
 */
public:
class FindAndReplace : Window , ButtonClickedListener
{

	private:	
	Combo findCombo;
	Combo replaceCombo;

	char[] findStr = "";
	char[] replaceStr = "";
	
	char[][char[]] listFindReplace;
	char[][] listFind;
	
	int findModes;
	
	Workspace workspace;

	int left = -1;
	int top = -1;
	
	public:
	this(Workspace workspace)
	{
		super("Find And Replace");
		this.workspace = workspace;
		findModes = 0;
		setBorderWidth(7);
		setup();
		setTransientFor(workspace);
	}
	
	void show()
	{

		if ( listFindReplace.length>0)
		{
			findCombo.setStrings(listFindReplace.keys);
			findCombo.setText(findStr);
			replaceCombo.setStrings(listFindReplace.values);
			replaceCombo.setText(replaceStr);
		}
		
		if (left>=0 )
		{
			move(left, top);
		}
		super.show();
	}
	
	void hide()
	{
		getPosition(&left, &top);
		super.hide();
	}
	
	private void setup()
	{
		VBox vbox = new VBox(false,4);
		
		findCombo = new Combo();
		replaceCombo = new Combo();
		
		vbox.packStart(findCombo,false,false,0);
		vbox.packStart(replaceCombo,false,false,0);

		Dispatcher dispatcher = Dispatcher.getDispatcher();
	

		Table table = new Table(2,2,true);
		
		CheckButton cbutton = new CheckButton("Match case");
		table.attach(cbutton,0,1,0,1,AttachOptions.FILL,AttachOptions.FILL,2,2);
		//dispatcher.addButtonClickedListener(this,cbutton,"matchcase");

		cbutton = new CheckButton("Whole word");
		table.attach(cbutton,0,1,1,2,AttachOptions.FILL,AttachOptions.FILL,2,2);
		//dispatcher.addButtonClickedListener(this,cbutton,"wholeword");

		cbutton = new CheckButton("Word start");
		table.attach(cbutton,1,2,0,1,AttachOptions.FILL,AttachOptions.FILL,2,2);
		//dispatcher.addButtonClickedListener(this,cbutton,"wordstart");

		cbutton = new CheckButton("Reg exp");
		table.attach(cbutton,1,2,1,2,AttachOptions.FILL,AttachOptions.FILL,2,2);
		//dispatcher.addButtonClickedListener(this,cbutton,"regexp");

		vbox.packStart(table,false,false,0);

		table = new Table(2,2,true);
		
		Button button = new Button("_Find");
		table.attach(button,0,1,0,1,AttachOptions.FILL,AttachOptions.FILL,2,2);
		dispatcher.addButtonClickedListener(this,button,"find");

		button = new Button("_Replace & Find");
		table.attach(button,0,1,1,2,AttachOptions.FILL,AttachOptions.FILL,2,2);
		dispatcher.addButtonClickedListener(this,button,"replacefind");

		button = new Button("Replace");
		table.attach(button,1,2,0,1,AttachOptions.FILL,AttachOptions.FILL,2,2);
		dispatcher.addButtonClickedListener(this,button,"replace");

		button = new Button("_Cancel");
		table.attach(button,1,2,1,2,AttachOptions.FILL,AttachOptions.FILL,2,2);
		dispatcher.addButtonClickedListener(this,button,"cancel");

		Alignment alignment = new Alignment(1,0.5,1,1);
		alignment.add(table);
		vbox.packStart(alignment,false,true,0);
		
		add(vbox);
	}
	
	void buttonClickedCallback(Button button, char[] action)
	{
		bit cancel = false;
		bit replace = false;
		bit find = false;
		switch ( action )
		{
			case "find": // bo break
			case "replacefind":
				find = true;
				break;
			
			case "replace": //no break
			case "replacefind":
				replace = true;
				break;
				
			case "cancel": cancel = true; break;
			
			default:
				printf("find window action = %.*s\n",action);
				break;
		}
		
		hide();

		findStr = findCombo.getSelectedText();
		replaceStr = replaceCombo.getSelectedText();


		if ( !cancel )
		{
			//listFind ~= findStr;
			listFindReplace[findStr] = replaceStr;
			
			foreach(char[] key ; listFindReplace.keys)
			{
				printf("list fing [%.*s] = %.*s\n",key,listFindReplace[key]);
			}
			workspace.findReplace(findStr, replaceStr, replace,find,0, false);
		}
	}
	
}