/*
 * leds
 * Linux Editor for D 
 * S as in simple(superfluous) or supperb
 * 
 * by Antonio Monteiro
 */

module leds.Leds;

private import gc;

private import dui.All;

private import leds.Workspace;
private import leds.Properties;
//private import ext.dconf.DConf;

private import path;
alias path filePath;
private import stream;
private import string;

alias stream.File SFile;

public:
const int VERSION_MAJOR = 0;
const int VERSION_MINOR = 1;
const int VERSION_MICRO = 6;
const char[] VERSION_QUAL = "alpha";

private:
extern(C)
{
	 char* getenv(char*);
};

const char [] leadsHeaderMessage = 
"#"
"\n# leds preferences file"
"\n#"
"\n"
"\n#"
"\n# This file was generated automatically by leds"
"\n# editing this file is not recomended"
"\n#"
"\n"
"\n"
;


/**
 * leds
 */
public:
class Leds : PropertiesGUICaller
{
	
	private:

	Properties props;
	
	Workspace[] workspaces;

	int exitCode = 0;
	bit closing = false;

	/**
	 * When true leds won't open projects at startup
	 * setup by command line "-nop"
	 */
	bit noProjects = false;
	//DConf dConf;
	
	static char[] ledsHome;// = "~/.leds";
	static char[] ledsData;// = "~/.leds_data";
	
	static const char[] projectsDir = "projects";
	static const char[] projectExtension = "lpj";

	static Leds thisLeds;
	
	static public Leds leds()
	{
		printf("Leds.leds() %X Leds.leds() Leds.leds() Leds.leds() Leds.leds() Leds.leds() Leds.leds() Leds.leds() Leds.leds() \n",thisLeds);
		if ( thisLeds === null )
		{
			char[][] args;
			thisLeds = new Leds();
		printf("Leds.leds() %X \n",thisLeds);
			thisLeds.init(args);
		}
		printf("Leds.leds() exit %X \n",thisLeds);
		return thisLeds;
	}
	
	static public Leds leds(char[][]args)
	{
		printf("Leds.leds(args) %X Leds.leds(args) Leds.leds(args) Leds.leds(args) Leds.leds(args) Leds.leds(args)\n",thisLeds);
		if ( thisLeds === null )
		{
			thisLeds = new Leds();
		printf("Leds.leds(args) %X \n",thisLeds);
			thisLeds.init(args);
		}
		printf("Leds.leds(args) exit %X \n",thisLeds);
		return thisLeds;
	}

	private: this()
	{
	}
	
	private: void init(char[][]args)
	{
		ledsHome = filePath.join(getUserHome(),".leds");
		ledsData = filePath.join(getUserHome(),".leds_data");

		//dConf = new DConf();

		setProps();
	
		char[][] filesToOpen;
		bit exitNow = parseArgs(args, filesToOpen);

		if ( exitNow )
		{
			closing = true;
		}
		else
		{
			printf("Using home %.*s\n",ledsHome);
			printf("Using data %.*s\n",ledsData);
			Workspace workspace = new Workspace(this, !noProjects);
			workspace.openFiles(filesToOpen);
			workspaces ~= workspace;
			printf("Leds before workspace show\n");
			workspace.show();
			printf("Leds after workspace show\n");
		}
	}
	
	public:
	
	/**
	 * loops through the args to process each one.
	 * @param args the args
	 * @param filesToOpen the files to open from the command line
	 * @return true if we should exit the program
	 */
	bit parseArgs(char[][] args, inout char[][] filesToOpen)
	{
		int i = 1;
		while ( i>0 && i < args.length )
		{
			char [] arg = args[i];
			if ( arg[0] == '-' )
			{
				i = processOption(i,args);
			}
			else
			{
				filesToOpen ~= arg;
				++i;
			}
		}
		
		return i<0;
	}

	/**
	 * processes one option and returns the next offset value.
	 * @return the next offset value or -1 if the program should exit
	 */
	int processOption(int offset, char[][] args)
	{
		switch(args[offset])
		{
			case "-home":
				ledsHome = args[++offset];
				break;
				
			case "-data":
				ledsData = args[++offset];
				break;

			case "-nop": // no break
			case "--nop":
				noProjects = true;
				break;
				
			case "-h":
			case "--help":
				printf(getAppName() ~ "\n\0");
				printf( "usage: leds [options] files -GTK[GTK options]\n\n"
						"options:\n"
						"  -h, --help     print this help and exit\n"
						"  -v, --version  print leds version and exit\n"
						" --home          specify leds home directory [default ~/.leds]\n"
						" --data          specify leds data directory [default ~/.leds_data]\n"
						"\n"
						"files            files to open\n"
						"-GTK             subsequente areguments will not be process by leds\n"
						"                 but will be passed to GTK\n"
						);
				offset = -2;
				break;
				
			case "-v":
			case "--version":
				printf(getAppName() ~ "\n\0");
				offset = -2;
				break;
			
			default:
				printf("Unknown option %.*s ignored\n",args[offset]);
				break;
		}
		++offset;
		return offset;
	}
	
	/**
	 * saves the preferences and exits
	 * @param code the code that generated this exit request
	 * @param force if true the program will exit anyway
	 * @return true it the exit should proced false if the application should not exit
	 */
	public bit exit(int code, bit force)
	{
		exitCode = code;
		closing = true;
		
		return true;
	}

	public char[] getHomeDir()
	{
		return ledsHome;
	}
	
	public char[] getDataDir()
	{
		return ledsData;
	}

	public char[] getUser()
	{
		return string.toString(getenv("USER\0"));
	}

	public char[] getUserHome()
	{
		return string.toString(getenv("HOME\0"));
	}

	public char[] getProjectsDir()
	{
		return filePath.join(getDataDir(),projectsDir);
	}

	public char[] getProjectExtension()
	{
		return projectExtension;
	}
	
	public char[] getProjectFileName(char[] name)
	{
		char[] filename = filePath.join(getProjectsDir(),name);
		return filePath.addExt(filename,projectExtension);
	}

	void setProps()
	{
		props = new Properties();
		
		props.add(PropsTypes.TEXT, "dmd:", "", "dmd","","");
		props.add(PropsTypes.DIRECTORY, "phobos:", "", "phobos","","");
		props.add(PropsTypes.FILE, "DUI:", "", "dui","","");
		props.add(PropsTypes.YES_NO, "duiEXT:", "", "use dui extensions","","");
		props.add(PropsTypes.YES_NO, "duiGL:", "", "use dui openGL","","");

		props.add(PropsTypes.TEXT, "goCommand:", "", "Set 'go' command","run","Workspace");
		props.add(PropsTypes.TEXT, "execCommand:", "", "Set 'Execute' command","build","Workspace");
		props.add(PropsTypes.TEXT, "stopCommand:", "", "Set 'stop' command","","Workspace");
		props.add(PropsTypes.YES_NO, "saveOnExit:", "", "yes","","Workspace");

		props.add(PropsTypes.YES_NO, "showHidden:", "no", "Show hidden files","","Projects");

		props.add(PropsTypes.YES_NO, "scrollOnWrite:", "yes", "Scroll on write","","Console");
		props.add(PropsTypes.YES_NO, "newOnRun:", "yes", "Open new for every run","","Console");

		props.add(PropsTypes.YES_NO, "lineNumbers:", "no", "Show line numbers","","Editor");
		props.add(PropsTypes.YES_NO, "codeFolding:", "no", "Code folding","","Editor");
		props.add(PropsTypes.YES_NO, "fastSearch:", "yes", "Fast search","","Editor");
		props.add(PropsTypes.YES_NO, "lineNumbers:", "no", "Show line numbers","","Editor");

		// non visible props

		props.add(PropsTypes.INT, "main.left:", "0", "","","-");
		props.add(PropsTypes.INT, "main.top:", "0", "","","-");
		props.add(PropsTypes.INT, "main.width:", "550", "","","-");
		props.add(PropsTypes.INT, "main.height:", "650", "","","-");
		props.add(PropsTypes.INT, "main.leftPos:", "50", "","","-");
		props.add(PropsTypes.INT, "main.bottomPos:", "50", "","","-");
		props.add(PropsTypes.INT, "main.dummy:", "50", "","","-");

		props.load(filePath.join(getHomeDir(),"preferences.leds"));
		
	}

	void propertiesEditDone(Properties newProperties)
	{
		props = newProperties;
		saveProps();
	}

	Properties getProps()
	{
		if ( props === null )
		{
			setProps();
		}
		return props;
	}
	
	public void editPreferences()
	{
		new PropertiesGUISetup(this, workspaces[0]);
	}
	
	char[] getPropValue(char[] key, char[] defaultValue)
	{
		return props.get(key,defaultValue);
	}
		
	int getPropValue(char[] key, int defaultValue)
	{
		return props.get(key,defaultValue);
	}
		
	void setPropValue(char[] key, char[] defaultValue)
	{
		props.set(key,defaultValue);
	}
		
	void setPropValue(char[] key, int defaultValue)
	{
		props.set(key,defaultValue);
	}

	void saveProps()
	{
		props.save(filePath.join(getHomeDir(),"preferences.leds"),leadsHeaderMessage);
		props.dump();
	}
		
};


char[] getVersionString()
{
	return string.toString(VERSION_MAJOR) 
			~ "." ~ string.toString(VERSION_MINOR) 
			~ "." ~ string.toString(VERSION_MICRO) 
			~ " " ~ VERSION_QUAL;
};

char[] getAppName()
{
	version(win32)
	{
		return "leds (Light Editor for D (Simple)), version " ~ getVersionString();
	}
	version(linux)
	{
		return "leds (Linux Editor for D (Simple)), version " ~ getVersionString();
	}
};

int main(char [][]args)
{
	DUI dui;

	dui = DUI.dui(args);
	//DConf.init(args);

	Dispatcher dispatcher = Dispatcher.getDispatcher();

	Leds leds = Leds.leds(args);
	
	if ( !leds.closing )
	{
		dui.go();
	}

	return leds.exitCode;
	
}
