module gl.Scintilla;

import gl.gl;

alias char uchar;

//## First line may be used for shbang

//## This file defines the interface to Scintilla

//## Copyright 2000-2003 by Neil Hodgson <neilh@scintilla.org>
//## The License.txt file describes the conditions under which this software may be distributed.

//## A line starting with ## is a pure comment and should be stripped by readers.
//## A line starting with #! is for future shbang use
//## A line starting with # followed by a space is a documentation comment and refers
//## to the next feature definition.

//## Each feature is defined by a line starting with fun, get, set, public const int or evt.
//##     //cat -> start a category
//##     //fun -> a function
//##     //get -> a property //get function
//##     //set  -> a property //set  function
//##     public const int -> definition of a constant
//##     evt -> an event
//##     //enu -> associate an enumeration with a //set  of vals with a prefix
//##     lex -> associate a lexer with the lexical classes it produces
//##
//## All other feature names should be ignored. They may be defined in the future.
//## A property may have a //set  function, a //get function or both. Each will have
//## "Get" or "Set" in their names and the corresponding name will have the obvious switch.
//## A property may be subscripted, in which case the first parameter is the subscript.
//## fun, get, and //set  features have a strict syntax:
//## <featureType><ws><returnType><ws><name>[=<number](<param>,<param>)
//## param is <paramType><ws><paramName>[=<value>]
//## Additional white space is allowed between elements.
//## The syntax for evt is <featureType><ws><returnType><ws><name>[=<number]([<param>[,<param>]*])
//## Feature names that contain an underscore are defined by Windows, so in these
//## cases, using the Windows definition is preferred where available.
//## The feature numbers are stable so features will not be renumbered.
//## Features may be removed but they will go through a period of deprecation
//## before remopublic const int which is signalled by moving them into the Deprecated category.
//##
//## //enu has the syntax enu<ws><enumeration>=<prefix>[<ws><prefix>]* where all the val
//## features in this file starting with a given <prefix> are considered part of the
//## enumeration.
//##
//## lex has the syntax lex<ws><name>=<lexerVal><ws><prefix>[<ws><prefix>]*
//## where name is a reasonably capitalised (Python, XML) identifier or UI name,
//## lexerpublic const int is the public const int used to specify the lexer, and the list of prefixes is similar
//## to enu. The name may not be the same as that used within the lexer so the lexerVal
//## should be used to tie these entities together.

//## Types:
//##     void
//##     int
//##     bool -> integer, 1=true, 0=false
//##     position -> integer position in a document
//##     colour -> colour integer containing red, green and blue bytes.
//##     string -> pointer to character
//##     stringresult -> pointer to character
//##     cells -> pointer to array of cells, each cell containing a style byte and character byte
//##     textrange -> range of a min and a max position with an output string
//##     findtext -> searchrange, text -> foundposition
//##     keymod -> integer containing key in low half and modifiers in high half
//##     formatrange
//## Types no longer used:
//##     findtextex -> searchrange
//##     charrange -> range of a min and a max position
//##     charrangeresult -> like charrange, but output param
//##     countedstring
//##     point -> x,y
//##     pointresult  -> like point, but output param
//##     rectangle -> left,top,right,bottom
//## Client code should ignore definitions containing types it does not understand, except
//## for possibly #defining the constants

//## String arguments may contain NUL ('\0') characters where the calls provide a length
//## argument and retrieve NUL characters. All retrieved strings except for those retrieved
//## by GetLine also have a NUL appended but client code should calculate the size that
//## will be returned rather than relying upon the NUL whenever possible. Allow for the
//## extra NUL character when allocating buffers.

//cat Basics

//################################################
//## For Scintilla.h
public const int INVALID_POSITION=-1
//# Define start of Scintilla messages to be greater than all edit (EM_*) messages
//# as many EM_ messages can be used although that use is deprecated.
public const int SCI_START=2000
public const int SCI_OPTIONAL_START=3000
public const int SCI_LEXER_START=4000

//# Add text to the document.
//fun void AddText=2001(int length, string text)

//# Add array of cells to document.
//fun void AddStyledText=2002(int length, cells c)

//# Insert string at a position.
//fun void InsertText=2003(position pos, string text)

//# Delete all text in the document.
//fun void ClearAll=2004(,)

//# //set  all style bytes to 0, remove all folding information.
//fun void ClearDocumentStyle=2005(,)

//# The number of characters in the document.
//get int GetLength=2006(,)

//# Returns the character byte at the position.
//get int GetCharAt=2007(position pos,)

//# Returns the position of the caret.
//get position GetCurrentPos=2008(,)

//# Returns the position of the opposite end of the selection to the caret.
//get position GetAnchor=2009(,)

//# Returns the style byte at the position.
//get int GetStyleAt=2010(position pos,)

//# Redoes the next action on the undo history.
//fun void Redo=2011(,)

//# Choose between collecting actions into the undo
//# history and discarding them.
//set  void SetUndoCollection=2012(bool collectUndo,)

//# Select all the text in the document.
//fun void SelectAll=2013(,)

//# Remember the current position in the undo history as the position
//# at which the document was saved.
//fun void SetSavePoint=2014(,)

//# Retrieve a buffer of cells.
//# Returns the number of bytes in the buffer not including terminating nulls.
//fun int GetStyledText=2015(, textrange tr)

//# Are there any redoable actions in the undo history?
//fun bool CanRedo=2016(,)

//# Retrieve the line number at which a particular marker is located.
//fun int MarkerLineFromHandle=2017(int handle,)

//# Delete a marker.
//fun void MarkerDeleteHandle=2018(int handle,)

//# Is undo history being collected?
//get bool GetUndoCollection=2019(,)

//enu WhiteSpace=SCWS_
public const int SCWS_INVISIBLE=0
public const int SCWS_VISIBLEALWAYS=1
public const int SCWS_VISIBLEAFTERINDENT=2

//# Are white space characters currently visible?
//# Returns one of SCWS_* constants.
//get int GetViewWS=2020(,)

//# Make white space characters invisible, always visible or visible outside indentation.
//set  void SetViewWS=2021(int viewWS,)

//# Find the position from a point within the window.
//fun int PositionFromPoint=2022(int x, int y)

//# Find the position from a point within the window but return
//# INVALID_POSITION if not close to text.
//fun int PositionFromPointClose=2023(int x, int y)

//# //set  caret to start of a line and ensure it is visible.
//fun void GotoLine=2024(int line,)

//# //set  caret to a position and ensure it is visible.
//fun void GotoPos=2025(position pos,)

//# //set  the selection anchor to a position. The anchor is the opposite
//# end of the selection from the caret.
//set  void SetAnchor=2026(position posAnchor,)

//# Retrieve the text of the line containing the caret.
//# Returns the index of the caret on the line.
//fun int GetCurLine=2027(int length, stringresult text)

//# Retrieve the position of the last correctly styled character.
//get position GetEndStyled=2028(,)

//enu EndOfLine=SC_EOL_
public const int SC_EOL_CRLF=0
public const int SC_EOL_CR=1
public const int SC_EOL_LF=2

//# Convert all line endings in the document to one mode.
//fun void ConvertEOLs=2029(int eolMode,)

//# Retrieve the current end of line mode - one of CRLF, CR, or LF.
//get int GetEOLMode=2030(,)

//# //set  the current end of line mode.
//set  void SetEOLMode=2031(int eolMode,)

//# //set  the current styling position to pos and the styling mask to mask.
//# The styling mask can be used to protect some bits in each styling byte from modification.
//fun void StartStyling=2032(position pos, int mask)

//# Change style from current styling position for length characters to a style
//# and move the current styling position to after this newly styled segment.
//fun void SetStyling=2033(int length, int style)

//# Is drawing done first into a buffer or direct to the screen?
//get bool GetBufferedDraw=2034(,)

//# If drawing is buffered then each line of text is drawn into a bitmap buffer
//# before drawing it to the screen to avoid flicker.
//set  void SetBufferedDraw=2035(bool buffered,)

//# Change the visible size of a tab to be a multiple of the width of a space character.
//set  void SetTabWidth=2036(int tabWidth,)

//# Retrieve the visible size of a tab.
//get int GetTabWidth=2121(,)

//# The SC_CP_UTF8 value can be used to enter Unicode mode.
//# This is the same value as CP_UTF8 in Windows
public const int SC_CP_UTF8=65001

//# The SC_CP_DBCS value can be used to indicate a DBCS mode for GTK+.
public const int SC_CP_DBCS=1

//# //set  the code page used to interpret the bytes of the document as characters.
//# The SC_CP_UTF8 value can be used to enter Unicode mode.
//set  void SetCodePage=2037(int codePage,)

//# In palette mode, Scintilla uses the environment's palette calls to display
//# more colours. This may lead to ugly displays.
//set  void SetUsePalette=2039(bool usePalette,)

//enu MarkerSymbol=SC_MARK_
public const int MARKER_MAX=31
public const int SC_MARK_CIRCLE=0
public const int SC_MARK_ROUNDRECT=1
public const int SC_MARK_ARROW=2
public const int SC_MARK_SMALLRECT=3
public const int SC_MARK_SHORTARROW=4
public const int SC_MARK_EMPTY=5
public const int SC_MARK_ARROWDOWN=6
public const int SC_MARK_MINUS=7
public const int SC_MARK_PLUS=8

//# Shapes used for outlining column.
public const int SC_MARK_VLINE=9
public const int SC_MARK_LCORNER=10
public const int SC_MARK_TCORNER=11
public const int SC_MARK_BOXPLUS=12
public const int SC_MARK_BOXPLUSCONNECTED=13
public const int SC_MARK_BOXMINUS=14
public const int SC_MARK_BOXMINUSCONNECTED=15
public const int SC_MARK_LCORNERCURVE=16
public const int SC_MARK_TCORNERCURVE=17
public const int SC_MARK_CIRCLEPLUS=18
public const int SC_MARK_CIRCLEPLUSCONNECTED=19
public const int SC_MARK_CIRCLEMINUS=20
public const int SC_MARK_CIRCLEMINUSCONNECTED=21

//# Invisible mark that only sets the line background color.
public const int SC_MARK_BACKGROUND=22
public const int SC_MARK_DOTDOTDOT=23
public const int SC_MARK_ARROWS=24
public const int SC_MARK_PIXMAP=25

public const int SC_MARK_CHARACTER=10000

//enu MarkerOutline=SC_MARKNUM_
//# Markers used for outlining column.
public const int SC_MARKNUM_FOLDEREND=25
public const int SC_MARKNUM_FOLDEROPENMID=26
public const int SC_MARKNUM_FOLDERMIDTAIL=27
public const int SC_MARKNUM_FOLDERTAIL=28
public const int SC_MARKNUM_FOLDERSUB=29
public const int SC_MARKNUM_FOLDER=30
public const int SC_MARKNUM_FOLDEROPEN=31

public const int SC_MASK_FOLDERS=0xFE000000

//# //set  the symbol used for a particular marker number.
//fun void MarkerDefine=2040(int markerNumber, int markerSymbol)

//# //set  the foreground colour used for a particular marker number.
//fun void MarkerSetFore=2041(int markerNumber, colour fore)

//# //set  the background colour used for a particular marker number.
//fun void MarkerSetBack=2042(int markerNumber, colour back)

//# Add a marker to a line, returning an ID which can be used to find or delete the marker.
//fun int MarkerAdd=2043(int line, int markerNumber)

//# Delete a marker from a line.
//fun void MarkerDelete=2044(int line, int markerNumber)

//# Delete all markers with a particular number from all lines.
//fun void MarkerDeleteAll=2045(int markerNumber,)

//# //get a bit mask of all the markers //set  on a line.
//fun int MarkerGet=2046(int line,)

//# Find the next line after lineStart that includes a marker in mask.
//fun int MarkerNext=2047(int lineStart, int markerMask)

//# Find the previous line before lineStart that includes a marker in mask.
//fun int MarkerPrevious=2048(int lineStart, int markerMask)

//# Define a marker from a pixmap.
//fun void MarkerDefinePixmap=2049(int markerNumber, string pixmap)

//enu MarginType=SC_MARGIN_
public const int SC_MARGIN_SYMBOL=0
public const int SC_MARGIN_NUMBER=1

//# //set  a margin to be either numeric or symbolic.
//set  void SetMarginTypeN=2240(int margin, int marginType)

//# Retrieve the type of a margin.
//get int GetMarginTypeN=2241(int margin,)

//# //set  the width of a margin to a width expressed in pixels.
//set  void SetMarginWidthN=2242(int margin, int pixelWidth)

//# Retrieve the width of a margin in pixels.
//get int GetMarginWidthN=2243(int margin,)

//# //set  a mask that determines which markers are displayed in a margin.
//set  void SetMarginMaskN=2244(int margin, int mask)

//# Retrieve the marker mask of a margin.
//get int GetMarginMaskN=2245(int margin,)

//# Make a margin sensitive or insensitive to mouse clicks.
//set  void SetMarginSensitiveN=2246(int margin, bool sensitive)

//# Retrieve the mouse click sensitivity of a margin.
//get bool GetMarginSensitiveN=2247(int margin,)

//# Styles in range 32..37 are predefined for parts of the UI and are not used as normal styles.
//# Styles 38 and 39 are for future use.
//enu StylesCommon=STYLE_
public const int STYLE_DEFAULT=32
public const int STYLE_LINENUMBER=33
public const int STYLE_BRACELIGHT=34
public const int STYLE_BRACEBAD=35
public const int STYLE_CONTROLCHAR=36
public const int STYLE_INDENTGUIDE=37
public const int STYLE_LASTPREDEFINED=39
public const int STYLE_MAX=127

//# Character //set  identifiers are used in StyleSetCharacterSet.
//# The values are the same as the Windows *_CHAR//set  values.
//enu CharacterSet=SC_CHARSET_
public const int SC_CHARSET_ANSI=0
public const int SC_CHARSET_DEFAULT=1
public const int SC_CHARSET_BALTIC=186
public const int SC_CHARSET_CHINESEBIG5=136
public const int SC_CHARSET_EASTEUROPE=238
public const int SC_CHARSET_GB2312=134
public const int SC_CHARSET_GREEK=161
public const int SC_CHARSET_HANGUL=129
public const int SC_CHARSET_MAC=77
public const int SC_CHARSET_OEM=255
public const int SC_CHARSET_RUSSIAN=204
public const int SC_CHARSET_SHIFTJIS=128
public const int SC_CHARSET_SYMBOL=2
public const int SC_CHARSET_TURKISH=162
public const int SC_CHARSET_JOHAB=130
public const int SC_CHARSET_HEBREW=177
public const int SC_CHARSET_ARABIC=178
public const int SC_CHARSET_VIETNAMESE=163
public const int SC_CHARSET_THAI=222

//# Clear all the styles and make equivalent to the global default style.
//set  void StyleClearAll=2050(,)

//# //set  the foreground colour of a style.
//set  void StyleSetFore=2051(int style, colour fore)

//# //set  the background colour of a style.
//set  void StyleSetBack=2052(int style, colour back)

//# //set  a style to be bold or not.
//set  void StyleSetBold=2053(int style, bool bold)

//# //set  a style to be italic or not.
//set  void StyleSetItalic=2054(int style, bool italic)

//# //set  the size of characters of a style.
//set  void StyleSetSize=2055(int style, int sizePoints)

//# //set  the font of a style.
//set  void StyleSetFont=2056(int style, string fontName)

//# //set  a style to have its end of line filled or not.
//set  void StyleSetEOLFilled=2057(int style, bool filled)

//# Re//set  the default style to its state at startup
//fun void StyleResetDefault=2058(,)

//# //set  a style to be underlined or not.
//set  void StyleSetUnderline=2059(int style, bool underline)

//enu CaseVisible=SC_CASE_
public const int SC_CASE_MIXED=0
public const int SC_CASE_UPPER=1
public const int SC_CASE_LOWER=2
//# //set  a style to be mixed case, or to force upper or lower case.
//set  void StyleSetCase=2060(int style, int caseForce)

//# //set  the character //set  of the font in a style.
//set  void StyleSetCharacterSet=2066(int style, int characterSet)

//# //set  a style to be a hotspot or not.
//set  void StyleSetHotSpot=2409(int style, bool hotspot)

//# //set  the foreground colour of the selection and whether to use this setting.
//fun void SetSelFore=2067(bool useSetting, colour fore)

//# //set  the background colour of the selection and whether to use this setting.
//fun void SetSelBack=2068(bool useSetting, colour back)

//# //set  the foreground colour of the caret.
//set  void SetCaretFore=2069(colour fore,)

//# When key+modifier combination km is pressed perform msg.
//fun void AssignCmdKey=2070(keymod km, int msg)

//# When key+modifier combination km do nothing.
//fun void ClearCmdKey=2071(keymod km,)

//# Drop all key mappings.
//fun void ClearAllCmdKeys=2072(,)

//# //set  the styles for a segment of the document.
//fun void SetStylingEx=2073(int length, string styles)

//# //set  a style to be visible or not.
//set  void StyleSetVisible=2074(int style, bool visible)

//# //get the time in milliseconds that the caret is on and off.
//get int GetCaretPeriod=2075(,)

//# //get the time in milliseconds that the caret is on and off. 0 = steady on.
//set  void SetCaretPeriod=2076(int periodMilliseconds,)

//# //set  the //set  of characters making up words for when moving or selecting by word.
//set  void SetWordChars=2077(, string characters)

//# Start a sequence of actions that is undone and redone as a unit.
//# May be nested.
//fun void BeginUndoAction=2078(,)

//# End a sequence of actions that is undone and redone as a unit.
//fun void EndUndoAction=2079(,)

//enu IndicatorStyle=INDIC_
public const int INDIC_MAX=7
public const int INDIC_PLAIN=0
public const int INDIC_SQUIGGLE=1
public const int INDIC_TT=2
public const int INDIC_DIAGONAL=3
public const int INDIC_STRIKE=4
public const int INDIC_HIDDEN=5
public const int INDIC_BOX=6
public const int INDIC0_MASK=0x20
public const int INDIC1_MASK=0x40
public const int INDIC2_MASK=0x80
public const int INDICS_MASK=0xE0

//# //set  an indicator to plain, squiggle or TT.
//set  void IndicSetStyle=2080(int indic, int style)

//# Retrieve the style of an indicator.
//get int IndicGetStyle=2081(int indic,)

//# //set  the foreground colour of an indicator.
//set  void IndicSetFore=2082(int indic, colour fore)

//# Retrieve the foreground colour of an indicator.
//get colour IndicGetFore=2083(int indic,)

//# //set  the foreground colour of all whitespace and whether to use this setting.
//fun void SetWhitespaceFore=2084(bool useSetting, colour fore)

//# //set  the background colour of all whitespace and whether to use this setting.
//fun void SetWhitespaceBack=2085(bool useSetting, colour back)

//# Divide each styling byte into lexical class bits (default: 5) and indicator
//# bits (default: 3). If a lexer requires more than 32 lexical states, then this
//# is used to expand the possible states.
//set  void SetStyleBits=2090(int bits,)

//# Retrieve number of bits in style bytes used to hold the lexical state.
//get int GetStyleBits=2091(,)

//# Used to hold extra styling information for each line.
//set  void SetLineState=2092(int line, int state)

//# Retrieve the extra styling information for a line.
//get int GetLineState=2093(int line,)

//# Retrieve the last line number that has line state.
//get int GetMaxLineState=2094(,)

//# Is the background of the line containing the caret in a different colour?
//get bool GetCaretLineVisible=2095(,)

//# Display the background of the line containing the caret in a different colour.
//set  void SetCaretLineVisible=2096(bool show,)

//# //get the colour of the background of the line containing the caret.
//get colour GetCaretLineBack=2097(,)

//# //set  the colour of the background of the line containing the caret.
//set  void SetCaretLineBack=2098(colour back,)

//# //set  a style to be changeable or not (read only).
//# Experimental feature, currently buggy.
//set  void StyleSetChangeable=2099(int style, bool changeable)

//# Display a auto-completion list.
//# The lenEntered parameter indicates how many characters before
//# the caret should be used to provide context.
//fun void AutoCShow=2100(int lenEntered, string itemList)

//# Remove the auto-completion list from the screen.
//fun void AutoCCancel=2101(,)

//# Is there an auto-completion list visible?
//fun bool AutoCActive=2102(,)

//# Retrieve the position of the caret when the auto-completion list was displayed.
//fun position AutoCPosStart=2103(,)

//# User has selected an item so remove the list and insert the selection.
//fun void AutoCComplete=2104(,)

//# Define a //set  of character that when typed cancel the auto-completion list.
//fun void AutoCStops=2105(, string characterSet)

//# Change the separator character in the string setting up an auto-completion list.
//# Default is space but can be changed if items contain space.
//set  void AutoCSetSeparator=2106(int separatorCharacter,)

//# Retrieve the auto-completion list separator character.
//get int AutoCGetSeparator=2107(,)

//# Select the item in the auto-completion list that starts with a string.
//fun void AutoCSelect=2108(, string text)

//# Should the auto-completion list be cancelled if the user backspaces to a
//# position before where the box was created.
//set  void AutoCSetCancelAtStart=2110(bool cancel,)

//# Retrieve whether auto-completion cancelled by backspacing before start.
//get bool AutoCGetCancelAtStart=2111(,)

//# Define a //set  of characters that when typed will cause the autocompletion to
//# choose the selected item.
//set  void AutoCSetFillUps=2112(, string characterSet)

//# Should a single item auto-completion list automatically choose the item.
//set  void AutoCSetChooseSingle=2113(bool chooseSingle,)

//# Retrieve whether a single item auto-completion list automatically choose the item.
//get bool AutoCGetChooseSingle=2114(,)

//# //set  whether case is significant when performing auto-completion searches.
//set  void AutoCSetIgnoreCase=2115(bool ignoreCase,)

//# Retrieve state of ignore case flag.
//get bool AutoCGetIgnoreCase=2116(,)

//# Display a list of strings and send notification when user chooses one.
//fun void UserListShow=2117(int listType, string itemList)

//# //set  whether or not autocompletion is hidden automatically when nothing matches.
//set  void AutoCSetAutoHide=2118(bool autoHide,)

//# Retrieve whether or not autocompletion is hidden automatically when nothing matches.
//get bool AutoCGetAutoHide=2119(,)

//# //set  whether or not autocompletion deletes any word characters
//# after the inserted text upon completion.
//set  void AutoCSetDropRestOfWord=2270(bool dropRestOfWord,)

//# Retrieve whether or not autocompletion deletes any word characters
//# after the inserted text upon completion.
//get bool AutoCGetDropRestOfWord=2271(,)

//# Register an XPM image for use in autocompletion lists.
//fun void RegisterImage=2405(int type, string xpmData)

//# Clear all the registered XPM images.
//fun void ClearRegisteredImages=2408(,)

//# Retrieve the auto-completion list type-separator character.
//get int AutoCGetTypeSeparator=2285(,)

//# Change the type-separator character in the string setting up an auto-completion list.
//# Default is '?' but can be changed if items contain '?'.
//set  void AutoCSetTypeSeparator=2286(int separatorCharacter,)

//# //set  the number of spaces used for one level of indentation.
//set  void SetIndent=2122(int indentSize,)

//# Retrieve indentation size.
//get int GetIndent=2123(,)

//# Indentation will only use space characters if useTabs is false, otherwise
//# it will use a combination of tabs and spaces.
//set  void SetUseTabs=2124(bool useTabs,)

//# Retrieve whether tabs will be used in indentation.
//get bool GetUseTabs=2125(,)

//# Change the indentation of a line to a number of columns.
//set  void SetLineIndentation=2126(int line, int indentSize)

//# Retrieve the number of columns that a line is indented.
//get int GetLineIndentation=2127(int line,)

//# Retrieve the position before the first non indentation character on a line.
//get position GetLineIndentPosition=2128(int line,)

//# Retrieve the column number of a position, taking tab width into account.
//get int GetColumn=2129(position pos,)

//# Show or hide the horizontal scroll bar.
//set  void SetHScrollBar=2130(bool show,)

//# Is the horizontal scroll bar visible?
//get bool GetHScrollBar=2131(,)

//# Show or hide indentation guides.
//set  void SetIndentationGuides=2132(bool show,)

//# Are the indentation guides visible?
//get bool GetIndentationGuides=2133(,)

//# //set  the highlighted indentation guide column.
//# 0 = no highlighted guide.
//set  void SetHighlightGuide=2134(int column,)

//# //get the highlighted indentation guide column.
//get int GetHighlightGuide=2135(,)

//# //get the position after the last visible characters on a line.
//get int GetLineEndPosition=2136(int line,)

//# //get the code page used to interpret the bytes of the document as characters.
//get int GetCodePage=2137(,)

//# //get the foreground colour of the caret.
//get colour GetCaretFore=2138(,)

//# In palette mode?
//get bool GetUsePalette=2139(,)

//# In read-only mode?
//get bool GetReadOnly=2140(,)

//# Sets the position of the caret.
//set  void SetCurrentPos=2141(position pos,)

//# Sets the position that starts the selection - this becomes the anchor.
//set  void SetSelectionStart=2142(position pos,)

//# Returns the position at the start of the selection.
//get position GetSelectionStart=2143(,)

//# Sets the position that ends the selection - this becomes the currentPosition.
//set  void SetSelectionEnd=2144(position pos,)

//# Returns the position at the end of the selection.
//get position GetSelectionEnd=2145(,)

//# Sets the print magnification added to the point size of each style for printing.
//set  void SetPrintMagnification=2146(int magnification,)

//# Returns the print magnification.
//get int GetPrintMagnification=2147(,)

//enu PrintOption=SC_PRINT_
//# PrintColourMode - use same colours as screen.
public const int SC_PRINT_NORMAL=0
//# PrintColourMode - invert the light value of each style for printing.
public const int SC_PRINT_INVERTLIGHT=1
//# PrintColourMode - force black text on white background for printing.
public const int SC_PRINT_BLACKONWHITE=2
//# PrintColourMode - text stays coloured, but all background is forced to be white for printing.
public const int SC_PRINT_COLOURONWHITE=3
//# PrintColourMode - only the default-background is forced to be white for printing.
public const int SC_PRINT_COLOURONWHITEDEFAULTBG=4

//# Modify colours when printing for clearer printed text.
//set  void SetPrintColourMode=2148(int mode,)

//# Returns the print colour mode.
//get int GetPrintColourMode=2149(,)

//enu FindOption=SCFIND_
public const int SCFIND_WHOLEWORD=2
public const int SCFIND_MATCHCASE=4
public const int SCFIND_WORDSTART=0x00100000
public const int SCFIND_REGEXP=0x00200000
public const int SCFIND_POSIX=0x00400000

//# Find some text in the document.
//fun position FindText=2150(int flags, findtext ft)

//# On Windows, will draw the document into a display context such as a printer.
//fun void FormatRange=2151(bool draw, formatrange fr)

//# Retrieve the display line at the top of the display.
//get int GetFirstVisibleLine=2152(,)

//# Retrieve the contents of a line.
//# Returns the length of the line.
//fun int GetLine=2153(int line, stringresult text)

//# Returns the number of lines in the document. There is always at least one.
//get int GetLineCount=2154(,)

//# Sets the size in pixels of the left margin.
//set  void SetMarginLeft=2155(, int pixelWidth)

//# Returns the size in pixels of the left margin.
//get int GetMarginLeft=2156(,)

//# Sets the size in pixels of the right margin.
//set  void SetMarginRight=2157(, int pixelWidth)

//# Returns the size in pixels of the right margin.
//get int GetMarginRight=2158(,)

//# Is the document different from when it was last saved?
//get bool GetModify=2159(,)

//# Select a range of text.
//fun void SetSel=2160(position start, position end)

//# Retrieve the selected text.
//# Return the length of the text.
//fun int GetSelText=2161(,stringresult text)

//# Retrieve a range of text.
//# Return the length of the text.
//fun int GetTextRange=2162(, textrange tr)

//# Draw the selection in normal style or with selection highlighted.
//fun void HideSelection=2163(bool normal,)

//# Retrieve the x value of the point in the window where a position is displayed.
//fun int PointXFromPosition=2164(, position pos)

//# Retrieve the y value of the point in the window where a position is displayed.
//fun int PointYFromPosition=2165(, position pos)

//# Retrieve the line containing a position.
//fun int LineFromPosition=2166(position pos,)

//# Retrieve the position at the start of a line.
//fun int PositionFromLine=2167(int line,)

//# Scroll horizontally and vertically.
//fun void LineScroll=2168(int columns, int lines)

//# Ensure the caret is visible.
//fun void ScrollCaret=2169(,)

//# Replace the selected text with the argument text.
//fun void ReplaceSel=2170(, string text)

//# //set  to read only or read write.
//set  void SetReadOnly=2171(bool readOnly,)

//# Null operation.
//fun void Null=2172(,)

//# Will a paste succeed?
//fun bool CanPaste=2173(,)

//# Are there any undoable actions in the undo history?
//fun bool CanUndo=2174(,)

//# Delete the undo history.
//fun void EmptyUndoBuffer=2175(,)

//# Undo one action in the undo history.
//fun void Undo=2176(,)

//# Cut the selection to the clipboard.
//fun void Cut=2177(,)

//# Copy the selection to the clipboard.
//fun void Copy=2178(,)

//# Paste the contents of the clipboard into the document replacing the selection.
//fun void Paste=2179(,)

//# Clear the selection.
//fun void Clear=2180(,)

//# Replace the contents of the document with the argument text.
//fun void SetText=2181(, string text)

//# Retrieve all the text in the document.
//# Returns number of characters retrieved.
//fun int GetText=2182(int length, stringresult text)

//# Retrieve the number of characters in the document.
//get int GetTextLength=2183(,)

//# Retrieve a pointer to a function that processes messages for this Scintilla.
//get int GetDirectFunction=2184(,)

//# Retrieve a pointer value to use as the first argument when calling
//# the function returned by GetDirectFunction.
//get int GetDirectPointer=2185(,)

//# //set  to overtype (true) or insert mode.
//set  void SetOvertype=2186(bool overtype,)

//# Returns true if overtype mode is active otherwise false is returned.
//get bool GetOvertype=2187(,)

//# //set  the width of the insert mode caret.
//set  void SetCaretWidth=2188(int pixelWidth,)

//# Returns the width of the insert mode caret.
//get int GetCaretWidth=2189(,)

//# Sets the position that starts the tar//get which is used for updating the
//# document without affecting the scroll position.
//set  void SetTargetStart=2190(position pos,)

//# //get the position that starts the target.
//get position GetTargetStart=2191(,)

//# Sets the position that ends the tar//get which is used for updating the
//# document without affecting the scroll position.
//set  void SetTargetEnd=2192(position pos,)

//# //get the position that ends the target.
//get position GetTargetEnd=2193(,)

//# Replace the tar//get text with the argument text.
//# Text is counted so it can contain nulls.
//# Returns the length of the replacement text.
//fun int ReplaceTarget=2194(int length, string text)

//# Replace the tar//get text with the argument text after \d processing.
//# Text is counted so it can contain nulls.
//# Looks for \d where d is between 1 and 9 and replaces these with the strings
//# matched in the last search operation which were surrounded by \( and \).
//# Returns the length of the replacement text including any change
//# caused by processing the \d patterns.
//fun int ReplaceTargetRE=2195(int length, string text)

//# Search for a counted string in the tar//get and //set  the tar//get to the found
//# range. Text is counted so it can contain nulls.
//# Returns length of range or -1 for failure in which case tar//get is not moved.
//fun int SearchInTarget=2197(int length, string text)

//# //set  the search flags used by SearchInTarget.
//set  void SetSearchFlags=2198(int flags,)

//# //get the search flags used by SearchInTarget.
//get int GetSearchFlags=2199(,)

//# Show a call tip containing a definition near position pos.
//fun void CallTipShow=2200(position pos, string definition)

//# Remove the call tip from the screen.
//fun void CallTipCancel=2201(,)

//# Is there an active call tip?
//fun bool CallTipActive=2202(,)

//# Retrieve the position where the caret was before displaying the call tip.
//fun position CallTipPosStart=2203(,)

//# Highlight a segment of the definition.
//fun void CallTipSetHlt=2204(int start, int end)

//# //set  the background colour for the call tip.
//set  void CallTipSetBack=2205(colour back,)

//# //set  the foreground colour for the call tip.
//set  void CallTipSetFore=2206(colour fore,)

//# //set  the foreground colour for the highlighted part of the call tip.
//set  void CallTipSetForeHlt=2207(colour fore,)

//# Find the display line of a document line taking hidden lines into account.
//fun int VisibleFromDocLine=2220(int line,)

//# Find the document line of a display line taking hidden lines into account.
//fun int DocLineFromVisible=2221(int lineDisplay,)

//enu FoldLevel=SC_FOLDLEVEL
public const int SC_FOLDLEVELBASE=0x400
public const int SC_FOLDLEVELWHITEFLAG=0x1000
public const int SC_FOLDLEVELHEADERFLAG=0x2000
public const int SC_FOLDLEVELBOXHEADERFLAG=0x4000
public const int SC_FOLDLEVELBOXFOOTERFLAG=0x8000
public const int SC_FOLDLEVELCONTRACTED=0x10000
public const int SC_FOLDLEVELUNINDENT=0x20000
public const int SC_FOLDLEVELNUMBERMASK=0x0FFF

//# //set  the fold level of a line.
//# This encodes an integer level along with flags indicating whether the
//# line is a header and whether it is effectively white space.
//set  void SetFoldLevel=2222(int line, int level)

//# Retrieve the fold level of a line.
//get int GetFoldLevel=2223(int line,)

//# Find the last child line of a header line.
//get int GetLastChild=2224(int line, int level)

//# Find the parent line of a child line.
//get int GetFoldParent=2225(int line,)

//# Make a range of lines visible.
//fun void ShowLines=2226(int lineStart, int lineEnd)

//# Make a range of lines invisible.
//fun void HideLines=2227(int lineStart, int lineEnd)

//# Is a line visible?
//get bool GetLineVisible=2228(int line,)

//# Show the children of a header line.
//set  void SetFoldExpanded=2229(int line, bool expanded)

//# Is a header line expanded?
//get bool GetFoldExpanded=2230(int line,)

//# Switch a header line between expanded and contracted.
//fun void ToggleFold=2231(int line,)

//# Ensure a particular line is visible by expanding any header line hiding it.
//fun void EnsureVisible=2232(int line,)

//enu FoldFlag=SC_FOLDFLAG_
public const int SC_FOLDFLAG_LINEBEFORE_EXPANDED=0x0002
public const int SC_FOLDFLAG_LINEBEFORE_CONTRACTED=0x0004
public const int SC_FOLDFLAG_LINEAFTER_EXPANDED=0x0008
public const int SC_FOLDFLAG_LINEAFTER_CONTRACTED=0x0010
public const int SC_FOLDFLAG_LEVELNUMBERS=0x0040
public const int SC_FOLDFLAG_BOX=0x0001

//# //set  some style options for folding.
//fun void SetFoldFlags=2233(int flags,)

//# Ensure a particular line is visible by expanding any header line hiding it.
//# Use the currently //set  visibility policy to determine which range to display.
//fun void EnsureVisibleEnforcePolicy=2234(int line,)

//# Sets whether a tab pressed when caret is within indentation indents.
//set  void SetTabIndents=2260(bool tabIndents,)

//# Does a tab pressed when caret is within indentation indent?
//get bool GetTabIndents=2261(,)

//# Sets whether a backspace pressed when caret is within indentation unindents.
//set  void SetBackSpaceUnIndents=2262(bool bsUnIndents,)

//# Does a backspace pressed when caret is within indentation unindent?
//get bool GetBackSpaceUnIndents=2263(,)

public const int SC_TIME_FOREVER=10000000

//# Sets the time the mouse must sit still to generate a mouse dwell event.
//set  void SetMouseDwellTime=2264(int periodMilliseconds,)

//# Retrieve the time the mouse must sit still to generate a mouse dwell event.
//get int GetMouseDwellTime=2265(,)

//# //get position of start of word.
//fun int WordStartPosition=2266(position pos, bool onlyWordCharacters)

//# //get position of end of word.
//fun int WordEndPosition=2267(position pos, bool onlyWordCharacters)

//enu Wrap=SC_WRAP_
public const int SC_WRAP_NONE=0
public const int SC_WRAP_WORD=1

//# Sets whether text is word wrapped.
//set  void SetWrapMode=2268(int mode,)

//# Retrieve whether text is word wrapped.
//get int GetWrapMode=2269(,)

//enu LineCache=SC_CACHE_
public const int SC_CACHE_NONE=0
public const int SC_CACHE_CARET=1
public const int SC_CACHE_PAGE=2
public const int SC_CACHE_DOCUMENT=3

//# Sets the degree of caching of layout information.
//set  void SetLayoutCache=2272(int mode,)

//# Retrieve the degree of caching of layout information.
//get int GetLayoutCache=2273(,)

//# Sets the document width assumed for scrolling.
//set  void SetScrollWidth=2274(int pixelWidth,)

//# Retrieve the document width assumed for scrolling.
//get int GetScrollWidth=2275(,)

//# Measure the pixel width of some text in a particular style.
//# Nul terminated text argument.
//# Does not handle tab or control characters.
//fun int TextWidth=2276(int style, string text)

//# Sets the scroll range so that maximum scroll position has
//# the last line at the bottom of the view (default).
//# Setting this to false allows scrolling one page below the last line.
//set  void SetEndAtLastLine=2277(bool endAtLastLine,)

//# Retrieve whether the maximum scroll position has the last
//# line at the bottom of the view.
//get int GetEndAtLastLine=2278(,)

//# Retrieve the height of a particular line of text in pixels.
//fun int TextHeight=2279(int line,)

//# Show or hide the vertical scroll bar.
//set  void SetVScrollBar=2280(bool show,)

//# Is the vertical scroll bar visible?
//get bool GetVScrollBar=2281(,)

//# Append a string to the end of the document without changing the selection.
//fun void AppendText=2282(int length, string text)

//# Is drawing done in two phases with backgrounds drawn before faoregrounds?
//get bool GetTwoPhaseDraw=2283(,)

//# In twoPhaseDraw mode, drawing is performed in two phases, first the background
//# and then the foreground. This avoids chopping off characters that overlap the next run.
//set  void SetTwoPhaseDraw=2284(bool twoPhase,)

//# Make the tar//get range start and end be the same as the selection range start and end.
//fun void TargetFromSelection=2287(,)

//# Join the lines in the target.
//fun void LinesJoin=2288(,)

//# Split the lines in the tar//get into lines that are less wide than pixelWidth
//# where possible.
//fun void LinesSplit=2289(int pixelWidth,)

//# //set  the colours used as a chequerboard pattern in the fold margin
//fun void SetFoldMarginColour=2290(bool useSetting, colour back)
//fun void SetFoldMarginHiColour=2291(bool useSetting, colour fore)

//## New messages go here

//## Start of key messages
//# Move caret down one line.
//fun void LineDown=2300(,)

//# Move caret down one line extending selection to new caret position.
//fun void LineDownExtend=2301(,)

//# Move caret up one line.
//fun void LineUp=2302(,)

//# Move caret up one line extending selection to new caret position.
//fun void LineUpExtend=2303(,)

//# Move caret left one character.
//fun void CharLeft=2304(,)

//# Move caret left one character extending selection to new caret position.
//fun void CharLeftExtend=2305(,)

//# Move caret right one character.
//fun void CharRight=2306(,)

//# Move caret right one character extending selection to new caret position.
//fun void CharRightExtend=2307(,)

//# Move caret left one word.
//fun void WordLeft=2308(,)

//# Move caret left one word extending selection to new caret position.
//fun void WordLeftExtend=2309(,)

//# Move caret right one word.
//fun void WordRight=2310(,)

//# Move caret right one word extending selection to new caret position.
//fun void WordRightExtend=2311(,)

//# Move caret to first position on line.
//fun void Home=2312(,)

//# Move caret to first position on line extending selection to new caret position.
//fun void HomeExtend=2313(,)

//# Move caret to last position on line.
//fun void LineEnd=2314(,)

//# Move caret to last position on line extending selection to new caret position.
//fun void LineEndExtend=2315(,)

//# Move caret to first position in document.
//fun void DocumentStart=2316(,)

//# Move caret to first position in document extending selection to new caret position.
//fun void DocumentStartExtend=2317(,)

//# Move caret to last position in document.
//fun void DocumentEnd=2318(,)

//# Move caret to last position in document extending selection to new caret position.
//fun void DocumentEndExtend=2319(,)

//# Move caret one page up.
//fun void PageUp=2320(,)

//# Move caret one page up extending selection to new caret position.
//fun void PageUpExtend=2321(,)

//# Move caret one page down.
//fun void PageDown=2322(,)

//# Move caret one page down extending selection to new caret position.
//fun void PageDownExtend=2323(,)

//# Switch from insert to overtype mode or the reverse.
//fun void EditToggleOvertype=2324(,)

//# Cancel any modes such as call tip or auto-completion list display.
//fun void Cancel=2325(,)

//# Delete the selection or if no selection, the character before the caret.
//fun void DeleteBack=2326(,)

//# If selection is empty or all on one line replace the selection with a tab character.
//# If more than one line selected, indent the lines.
//fun void Tab=2327(,)

//# Dedent the selected lines.
//fun void BackTab=2328(,)

//# Insert a new line, may use a CRLF, CR or LF depending on EOL mode.
//fun void NewLine=2329(,)

//# Insert a Form Feed character.
//fun void FormFeed=2330(,)

//# Move caret to before first visible character on line.
//# If already there move to first character on line.
//fun void VCHome=2331(,)

//# Like VCHome but extending selection to new caret position.
//fun void VCHomeExtend=2332(,)

//# Magnify the displayed text by increasing the sizes by 1 point.
//fun void ZoomIn=2333(,)

//# Make the displayed text smaller by decreasing the sizes by 1 point.
//fun void ZoomOut=2334(,)

//# Delete the word to the left of the caret.
//fun void DelWordLeft=2335(,)

//# Delete the word to the right of the caret.
//fun void DelWordRight=2336(,)

//# Cut the line containing the caret.
//fun void LineCut=2337(,)

//# Delete the line containing the caret.
//fun void LineDelete=2338(,)

//# Switch the current line with the previous.
//fun void LineTranspose=2339(,)

//# Duplicate the current line.
//fun void LineDuplicate=2404(,)

//# Transform the selection to lower case.
//fun void LowerCase=2340(,)

//# Transform the selection to upper case.
//fun void UpperCase=2341(,)

//# Scroll the document down, keeping the caret visible.
//fun void LineScrollDown=2342(,)

//# Scroll the document up, keeping the caret visible.
//fun void LineScrollUp=2343(,)

//# Delete the selection or if no selection, the character before the caret.
//# Will not delete the character before at the start of a line.
//fun void DeleteBackNotLine=2344(,)

//# Move caret to first position on display line.
//fun void HomeDisplay=2345(,)

//# Move caret to first position on display line extending selection to
//# new caret position.
//fun void HomeDisplayExtend=2346(,)

//# Move caret to last position on display line.
//fun void LineEndDisplay=2347(,)

//# Move caret to last position on display line extending selection to new
//# caret position.
//fun void LineEndDisplayExtend=2348(,)

//# These are like their namesakes Home(Extend)?, LineEnd(Extend)?, VCHome(Extend)?
//# except they behave differently when word-wrap is enabled:
//# They go first to the start / end of the display line, like (Home|LineEnd)Display
//# The difference is that, the cursor is already at the point, it goes on to the start
//# or end of the document line, as appropriate for (Home|LineEnd|VCHome)Extend.

//fun void HomeWrap=2349(,)
//fun void HomeWrapExtend=2450(,)
//fun void LineEndWrap=2451(,)
//fun void LineEndWrapExtend=2452(,)
//fun void VCHomeWrap=2453(,)
//fun void VCHomeWrapExtend=2454(,)

//# Copy the line containing the caret.
//fun void LineCopy=2455(,)

//# Move the caret inside current view if it's not there already.
//fun void MoveCaretInsideView=2401(,)

//# How many characters are on a line, not including end of line characters?
//fun int LineLength=2350(int line,)

//# Highlight the characters at two positions.
//fun void BraceHighlight=2351(position pos1, position pos2)

//# Highlight the character at a position indicating there is no matching brace.
//fun void BraceBadLight=2352(position pos,)

//# Find the position of a matching brace or INVALID_POSITION if no match.
//fun position BraceMatch=2353(position pos,)

//# Are the end of line characters visible?
//get bool GetViewEOL=2355(,)

//# Make the end of line characters visible or invisible.
//set  void SetViewEOL=2356(bool visible,)

//# Retrieve a pointer to the document object.
//get int GetDocPointer=2357(,)

//# Change the document object used.
//set  void SetDocPointer=2358(,int pointer)

//# //set  which document modification events are sent to the container.
//set  void SetModEventMask=2359(int mask,)

//enu EdgeVisualStyle=EDGE_
public const int EDGE_NONE=0
public const int EDGE_LINE=1
public const int EDGE_BACKGROUND=2

//# Retrieve the column number which text should be kept within.
//get int GetEdgeColumn=2360(,)

//# //set  the column number of the edge.
//# If text goes past the edge then it is highlighted.
//set  void SetEdgeColumn=2361(int column,)

//# Retrieve the edge highlight mode.
//get int GetEdgeMode=2362(,)

//# The edge may be displayed by a line (EDGE_LINE) or by highlighting text that
//# goes beyond it (EDGE_BACKGROUND) or not displayed at all (EDGE_NONE).
//set  void SetEdgeMode=2363(int mode,)

//# Retrieve the colour used in edge indication.
//get colour GetEdgeColour=2364(,)

//# Change the colour used in edge indication.
//set  void SetEdgeColour=2365(colour edgeColour,)

//# Sets the current caret position to be the search anchor.
//fun void SearchAnchor=2366(,)

//# Find some text starting at the search anchor.
//# Does not ensure the selection is visible.
//fun int SearchNext=2367(int flags, string text)

//# Find some text starting at the search anchor and moving backwards.
//# Does not ensure the selection is visible.
//fun int SearchPrev=2368(int flags, string text)

//# Retrieves the number of lines completely visible.
//get int LinesOnScreen=2370(,)

//# //set  whether a pop up m//enu is displayed automatically when the user presses
//# the wrong mouse button.
//fun void UsePopUp=2371(bool allowPopUp,)

//# Is the selection rectangular? The alternative is the more common stream selection.
//get bool SelectionIsRectangle=2372(,)

//# //set  the zoom level. This number of points is added to the size of all fonts.
//# It may be positive to magnify or negative to reduce.
//set  void SetZoom=2373(int zoom,)
//# Retrieve the zoom level.
//get int GetZoom=2374(,)

//# Create a new document object.
//# Starts with reference count of 1 and not selected into editor.
//fun int CreateDocument=2375(,)
//# Extend life of document.
//fun void AddRefDocument=2376(, int doc)
//# Release a reference to the document, deleting document if it fades to black.
//fun void ReleaseDocument=2377(, int doc)

//# //get which document modification events are sent to the container.
//get int GetModEventMask=2378(,)

//# Change internal focus flag.
//set  void SetFocus=2380(bool focus,)
//# //get internal focus flag.
//get bool GetFocus=2381(,)

//# Change error status - 0 = OK.
//set  void SetStatus=2382(int statusCode,)
//# //get error status.
//get int GetStatus=2383(,)

//# //set  whether the mouse is captured when its button is pressed.
//set  void SetMouseDownCaptures=2384(bool captures,)
//# //get whether mouse gets captured.
//get bool GetMouseDownCaptures=2385(,)

//enu CursorShape=SC_CURSOR
public const int SC_CURSORNORMAL=-1
public const int SC_CURSORWAIT=4
//# Sets the cursor to one of the SC_CURSOR* values.
//set  void SetCursor=2386(int cursorType,)
//# //get cursor type.
//get int GetCursor=2387(,)

//# Change the way control characters are displayed:
//# If symbol is < 32, keep the drawn way, else, use the given character.
//set  void SetControlCharSymbol=2388(int symbol,)
//# //get the way control characters are displayed.
//get int GetControlCharSymbol=2389(,)

//# Move to the previous change in capitalisation.
//fun void WordPartLeft=2390(,)
//# Move to the previous change in capitalisation extending selection
//# to new caret position.
//fun void WordPartLeftExtend=2391(,)
//# Move to the change next in capitalisation.
//fun void WordPartRight=2392(,)
//# Move to the next change in capitalisation extending selection
//# to new caret position.
//fun void WordPartRightExtend=2393(,)

//# Constants for use with SetVisiblePolicy, similar to SetCaretPolicy.
public const int VISIBLE_SLOP=0x01
public const int VISIBLE_STRICT=0x04
//# //set  the way the display area is determined when a particular line
//# is to be moved to by Find, FindNext, GotoLine, etc.
//fun void SetVisiblePolicy=2394(int visiblePolicy, int visibleSlop)

//# Delete back from the current position to the start of the line.
//fun void DelLineLeft=2395(,)

//# Delete forwards from the current position to the end of the line.
//fun void DelLineRight=2396(,)

//# //get and //set  the xOff//set  (ie, horizonal scroll position).
//set  void SetXOffset=2397(int newOffset,)
//get int GetXOffset=2398(,)

//# //set  the last x chosen value to be the caret x position
//fun void ChooseCaretX=2399(,)

//# //set  the focus to this Scintilla widget.
//# GTK+ Specific.
//fun void GrabFocus=2400(,)

//enu CaretPolicy = CARET_
//# Caret policy, used by SetXCaretPolicy and SetYCaretPolicy.
//# If CARET_SLOP is set, we can define a slop value: caretSlop.
//# This value defines an unwanted zone (UZ) where the caret is... unwanted.
//# This zone is defined as a number of pixels near the vertical margins,
//# and as a number of lines near the horizontal margins.
//# By keeping the caret away from the edges, it is seen within its context,
//# so it is likely that the identifier that the caret is on can be completely seen,
//# and that the current line is seen with some of the lines following it which are
//# often dependent on that line.
public const int CARET_SLOP=0x01
//# If CARET_STRICT is set, the policy is enforced... strictly.
//# The caret is centred on the display if slop is not set,
//# and cannot go in the UZ if slop is set.
public const int CARET_STRICT=0x04
//# If CARET_JUMPS is set, the display is moved more energetically
//# so the caret can move in the same direction longer before the policy is applied again.
public const int CARET_JUMPS=0x10
//# If CARET_EVEN is not set, instead of having symmetrical UZs,
//# the left and bottom UZs are extended up to right and top UZs respectively.
//# This way, we favour the displaying of useful information: the begining of lines,
//# where most code reside, and the lines after the caret, eg. the body of a function.
public const int CARET_EVEN=0x08

//# //set  the way the caret is kept visible when going sideway.
//# The exclusion zone is given in pixels.
//fun void SetXCaretPolicy=2402(int caretPolicy, int caretSlop)

//# //set  the way the line the caret is on is kept visible.
//# The exclusion zone is given in lines.
//fun void SetYCaretPolicy=2403(int caretPolicy, int caretSlop)

//# //set  printing to line wrapped (SC_WRAP_WORD) or not line wrapped (SC_WRAP_NONE).
//set  void SetPrintWrapMode=2406(int mode,)

//# Is printing line wrapped.
//get int GetPrintWrapMode=2407(,)

//# //set  a fore colour for active hotspots.
//set  void SetHotspotActiveFore=2410(bool useSetting, colour fore)

//# //set  a back colour for active hotspots.
//set  void SetHotspotActiveBack=2411(bool useSetting, colour back)

//# Enable / Disable underlining active hotspots.
//set  void SetHotspotActiveUnderline=2412(bool underline,)

//# Move caret between paragraphs (delimited by empty lines)
//fun void ParaDown=2413(,)
//fun void ParaDownExtend=2414(,)
//fun void ParaUp=2415(,)
//fun void ParaUpExtend=2416(,)

//# Given a valid document position, return the previous position taking code
//# page into account. Returns 0 if passed 0.
//fun position PositionBefore=2417(position pos,)

//# Given a valid document position, return the next position taking code
//# page into account. Maximum value returned is the last position in the document.
//fun position PositionAfter=2418(position pos,)

//# Copy a range of text to the clipboard. Positions are clipped into the document.
//fun void CopyRange=2419(position start, position end)

//# Copy argument text to the clipboard.
//fun void CopyText=2420(int length, string text)

//# Start notifying the container of all key presses and commands.
//fun void StartRecord=3001(,)

//# Stop notifying the container of all key presses and commands.
//fun void StopRecord=3002(,)

//# //set  the lexing language of the document.
//set  void SetLexer=4001(int lexer,)

//# Retrieve the lexing language of the document.
//get int GetLexer=4002(,)

//# Colourise a segment of the document using the current lexing language.
//fun void Colourise=4003(position start, position end)

//# //set  up a value that may be used by a lexer for some optional feature.
//set  void SetProperty=4004(string key, string value)

//# Maximum value of keyword//set  parameter of SetKeyWords.
public const int KEYWORDSET_MAX=8

//# //set  up the key words used by the lexer.
//set  void SetKeyWords=4005(int keywordSet, string keyWords)

//# //set  the lexing language of the document based on string name.
//set  void SetLexerLanguage=4006(, string language)

//# Load a lexer library (dll / so)
//fun void LoadLexerLibrary=4007(, string path)

//# Notifications
//# Type of modification and the action which caused the modification.
//# These are defined as a bit mask to make it easy to specify which notifications are wanted.
//# One bit is //set  from each of SC_MOD_* and SC_PERFORMED_*.
//enu ModificationFlags=SC_MOD_ SC_PERFORMED_ SC_LAST
public const int SC_MOD_INSERTTEXT=0x1
public const int SC_MOD_DELETETEXT=0x2
public const int SC_MOD_CHANGESTYLE=0x4
public const int SC_MOD_CHANGEFOLD=0x8
public const int SC_PERFORMED_USER=0x10
public const int SC_PERFORMED_UNDO=0x20
public const int SC_PERFORMED_REDO=0x40
public const int SC_LASTSTEPINUNDOREDO=0x100
public const int SC_MOD_CHANGEMARKER=0x200
public const int SC_MOD_BEFOREINSERT=0x400
public const int SC_MOD_BEFOREDELETE=0x800
public const int SC_MODEVENTMASKALL=0xF77

//# For compatibility, these go through the COMMAND notification rather than NOTIFY
//# and should have had exactly the same values as the EN_* constants.
//# Unfortunately the SETFOCUS and KILLFOCUS are flipped over from EN_*
//# As clients depend on these constants, this will not be changed.
public const int SCEN_CHANGE=768
public const int SCEN_SETFOCUS=512
public const int SCEN_KILLFOCUS=256

//# Symbolic key codes and modifier flags.
//# ASCII and other printable characters below 256.
//# Extended keys above 300.

//enu Keys=SCK_
public const int SCK_DOWN=300
public const int SCK_UP=301
public const int SCK_LEFT=302
public const int SCK_RIGHT=303
public const int SCK_HOME=304
public const int SCK_END=305
public const int SCK_PRIOR=306
public const int SCK_NEXT=307
public const int SCK_DELETE=308
public const int SCK_INSERT=309
public const int SCK_ESCAPE=7
public const int SCK_BACK=8
public const int SCK_TAB=9
public const int SCK_RETURN=13
public const int SCK_ADD=310
public const int SCK_SUBTRACT=311
public const int SCK_DIVIDE=312

//enu KeyMod=SCMOD_
public const int SCMOD_SHIFT=1
public const int SCMOD_CTRL=2
public const int SCMOD_ALT=4

//################################################
//# For SciLexer.h
//enu Lexer=SCLEX_
public const int SCLEX_CONTAINER=0
public const int SCLEX_NULL=1
public const int SCLEX_PYTHON=2
public const int SCLEX_CPP=3
public const int SCLEX_HTML=4
public const int SCLEX_XML=5
public const int SCLEX_PERL=6
public const int SCLEX_SQL=7
public const int SCLEX_VB=8
public const int SCLEX_PROPERTIES=9
public const int SCLEX_ERRORLIST=10
public const int SCLEX_MAKEFILE=11
public const int SCLEX_BATCH=12
public const int SCLEX_XCODE=13
public const int SCLEX_LATEX=14
public const int SCLEX_LUA=15
public const int SCLEX_DIFF=16
public const int SCLEX_CONF=17
public const int SCLEX_PASCAL=18
public const int SCLEX_AVE=19
public const int SCLEX_ADA=20
public const int SCLEX_LISP=21
public const int SCLEX_RUBY=22
public const int SCLEX_EIFFEL=23
public const int SCLEX_EIFFELKW=24
public const int SCLEX_TCL=25
public const int SCLEX_NNCRONTAB=26
public const int SCLEX_BULLANT=27
public const int SCLEX_VBSCRIPT=28
public const int SCLEX_ASP=29
public const int SCLEX_PHP=30
public const int SCLEX_BAAN=31
public const int SCLEX_MATLAB=32
public const int SCLEX_SCRIPTOL=33
public const int SCLEX_ASM=34
public const int SCLEX_CPPNOCASE=35
public const int SCLEX_FORTRAN=36
public const int SCLEX_F77=37
public const int SCLEX_CSS=38
public const int SCLEX_POV=39
public const int SCLEX_LOUT=40
public const int SCLEX_ESCRIPT=41
public const int SCLEX_PS=42
public const int SCLEX_NSIS=43
public const int SCLEX_MMIXAL=44
public const int SCLEX_CLW=45
public const int SCLEX_CLWNOCASE=46
public const int SCLEX_LOT=47
public const int SCLEX_YAML=48

//# When a lexer specifies its language as SCLEX_AUTOMATIC it receives a
//# value assigned in sequence from SCLEX_AUTOMATIC+1.
public const int SCLEX_AUTOMATIC=1000
//# Lexical states for SCLEX_PYTHON
lex Python=SCLEX_PYTHON SCE_P_
lex Ruby=SCLEX_RUBY SCE_P_
public const int SCE_P_DEFAULT=0
public const int SCE_P_COMMENTLINE=1
public const int SCE_P_NUMBER=2
public const int SCE_P_STRING=3
public const int SCE_P_CHARACTER=4
public const int SCE_P_WORD=5
public const int SCE_P_TRIPLE=6
public const int SCE_P_TRIPLEDOUBLE=7
public const int SCE_P_CLASSNAME=8
public const int SCE_P_DEFNAME=9
public const int SCE_P_OPERATOR=10
public const int SCE_P_IDENTIFIER=11
public const int SCE_P_COMMENTBLOCK=12
public const int SCE_P_STRINGEOL=13
//# Lexical states for SCLEX_CPP
lex Cpp=SCLEX_CPP SCE_C_
lex SQL=SCLEX_SQL SCE_C_
lex Pascal=SCLEX_PASCAL SCE_C_
lex TCL=SCLEX_TCL SCE_C_
lex BullAnt=SCLEX_BULLANT SCE_C_
public const int SCE_C_DEFAULT=0
public const int SCE_C_COMMENT=1
public const int SCE_C_COMMENTLINE=2
public const int SCE_C_COMMENTDOC=3
public const int SCE_C_NUMBER=4
public const int SCE_C_WORD=5
public const int SCE_C_STRING=6
public const int SCE_C_CHARACTER=7
public const int SCE_C_UUID=8
public const int SCE_C_PREPROCESSOR=9
public const int SCE_C_OPERATOR=10
public const int SCE_C_IDENTIFIER=11
public const int SCE_C_STRINGEOL=12
public const int SCE_C_VERBATIM=13
public const int SCE_C_REGEX=14
public const int SCE_C_COMMENTLINEDOC=15
public const int SCE_C_WORD2=16
public const int SCE_C_COMMENTDOCKEYWORD=17
public const int SCE_C_COMMENTDOCKEYWORDERROR=18
public const int SCE_C_GLOBALCLASS=19
//# Lexical states for SCLEX_HTML, SCLEX_XML
lex HTML=SCLEX_HTML SCE_H
lex XML=SCLEX_XML SCE_H
lex ASP=SCLEX_ASP SCE_H
lex PHP=SCLEX_PHP SCE_H
public const int SCE_H_DEFAULT=0
public const int SCE_H_TAG=1
public const int SCE_H_TAGUNKNOWN=2
public const int SCE_H_ATTRIBUTE=3
public const int SCE_H_ATTRIBUTEUNKNOWN=4
public const int SCE_H_NUMBER=5
public const int SCE_H_DOUBLESTRING=6
public const int SCE_H_SINGLESTRING=7
public const int SCE_H_OTHER=8
public const int SCE_H_COMMENT=9
public const int SCE_H_ENTITY=10
//# XML and ASP
public const int SCE_H_TAGEND=11
public const int SCE_H_XMLSTART=12
public const int SCE_H_XMLEND=13
public const int SCE_H_SCRIPT=14
public const int SCE_H_ASP=15
public const int SCE_H_ASPAT=16
public const int SCE_H_CDATA=17
public const int SCE_H_QUESTION=18
//# More HTML
public const int SCE_H_VALUE=19
//# X-Code
public const int SCE_H_XCCOMMENT=20
//# SGML
public const int SCE_H_SGML_DEFAULT=21
public const int SCE_H_SGML_COMMAND=22
public const int SCE_H_SGML_1ST_PARAM=23
public const int SCE_H_SGML_DOUBLESTRING=24
public const int SCE_H_SGML_SIMPLESTRING=25
public const int SCE_H_SGML_ERROR=26
public const int SCE_H_SGML_SPECIAL=27
public const int SCE_H_SGML_ENTITY=28
public const int SCE_H_SGML_COMMENT=29
public const int SCE_H_SGML_1ST_PARAM_COMMENT=30
public const int SCE_H_SGML_BLOCK_DEFAULT=31
//# Embedded Javascript
public const int SCE_HJ_START=40
public const int SCE_HJ_DEFAULT=41
public const int SCE_HJ_COMMENT=42
public const int SCE_HJ_COMMENTLINE=43
public const int SCE_HJ_COMMENTDOC=44
public const int SCE_HJ_NUMBER=45
public const int SCE_HJ_WORD=46
public const int SCE_HJ_KEYWORD=47
public const int SCE_HJ_DOUBLESTRING=48
public const int SCE_HJ_SINGLESTRING=49
public const int SCE_HJ_SYMBOLS=50
public const int SCE_HJ_STRINGEOL=51
public const int SCE_HJ_REGEX=52
//# ASP Javascript
public const int SCE_HJA_START=55
public const int SCE_HJA_DEFAULT=56
public const int SCE_HJA_COMMENT=57
public const int SCE_HJA_COMMENTLINE=58
public const int SCE_HJA_COMMENTDOC=59
public const int SCE_HJA_NUMBER=60
public const int SCE_HJA_WORD=61
public const int SCE_HJA_KEYWORD=62
public const int SCE_HJA_DOUBLESTRING=63
public const int SCE_HJA_SINGLESTRING=64
public const int SCE_HJA_SYMBOLS=65
public const int SCE_HJA_STRINGEOL=66
public const int SCE_HJA_REGEX=67
//# Embedded VBScript
public const int SCE_HB_START=70
public const int SCE_HB_DEFAULT=71
public const int SCE_HB_COMMENTLINE=72
public const int SCE_HB_NUMBER=73
public const int SCE_HB_WORD=74
public const int SCE_HB_STRING=75
public const int SCE_HB_IDENTIFIER=76
public const int SCE_HB_STRINGEOL=77
//# ASP VBScript
public const int SCE_HBA_START=80
public const int SCE_HBA_DEFAULT=81
public const int SCE_HBA_COMMENTLINE=82
public const int SCE_HBA_NUMBER=83
public const int SCE_HBA_WORD=84
public const int SCE_HBA_STRING=85
public const int SCE_HBA_IDENTIFIER=86
public const int SCE_HBA_STRINGEOL=87
//# Embedded Python
public const int SCE_HP_START=90
public const int SCE_HP_DEFAULT=91
public const int SCE_HP_COMMENTLINE=92
public const int SCE_HP_NUMBER=93
public const int SCE_HP_STRING=94
public const int SCE_HP_CHARACTER=95
public const int SCE_HP_WORD=96
public const int SCE_HP_TRIPLE=97
public const int SCE_HP_TRIPLEDOUBLE=98
public const int SCE_HP_CLASSNAME=99
public const int SCE_HP_DEFNAME=100
public const int SCE_HP_OPERATOR=101
public const int SCE_HP_IDENTIFIER=102
//# ASP Python
public const int SCE_HPA_START=105
public const int SCE_HPA_DEFAULT=106
public const int SCE_HPA_COMMENTLINE=107
public const int SCE_HPA_NUMBER=108
public const int SCE_HPA_STRING=109
public const int SCE_HPA_CHARACTER=110
public const int SCE_HPA_WORD=111
public const int SCE_HPA_TRIPLE=112
public const int SCE_HPA_TRIPLEDOUBLE=113
public const int SCE_HPA_CLASSNAME=114
public const int SCE_HPA_DEFNAME=115
public const int SCE_HPA_OPERATOR=116
public const int SCE_HPA_IDENTIFIER=117
//# PHP
public const int SCE_HPHP_DEFAULT=118
public const int SCE_HPHP_HSTRING=119
public const int SCE_HPHP_SIMPLESTRING=120
public const int SCE_HPHP_WORD=121
public const int SCE_HPHP_NUMBER=122
public const int SCE_HPHP_VARIABLE=123
public const int SCE_HPHP_COMMENT=124
public const int SCE_HPHP_COMMENTLINE=125
public const int SCE_HPHP_HSTRING_VARIABLE=126
public const int SCE_HPHP_OPERATOR=127
//# Lexical states for SCLEX_PERL
lex Perl=SCLEX_PERL SCE_PL_
public const int SCE_PL_DEFAULT=0
public const int SCE_PL_ERROR=1
public const int SCE_PL_COMMENTLINE=2
public const int SCE_PL_POD=3
public const int SCE_PL_NUMBER=4
public const int SCE_PL_WORD=5
public const int SCE_PL_STRING=6
public const int SCE_PL_CHARACTER=7
public const int SCE_PL_PUNCTUATION=8
public const int SCE_PL_PREPROCESSOR=9
public const int SCE_PL_OPERATOR=10
public const int SCE_PL_IDENTIFIER=11
public const int SCE_PL_SCALAR=12
public const int SCE_PL_ARRAY=13
public const int SCE_PL_HASH=14
public const int SCE_PL_SYMBOLTABLE=15
public const int SCE_PL_REGEX=17
public const int SCE_PL_REGSUBST=18
public const int SCE_PL_LONGQUOTE=19
public const int SCE_PL_BACKTICKS=20
public const int SCE_PL_DATASECTION=21
public const int SCE_PL_HERE_DELIM=22
public const int SCE_PL_HERE_Q=23
public const int SCE_PL_HERE_QQ=24
public const int SCE_PL_HERE_QX=25
public const int SCE_PL_STRING_Q=26
public const int SCE_PL_STRING_QQ=27
public const int SCE_PL_STRING_QX=28
public const int SCE_PL_STRING_QR=29
public const int SCE_PL_STRING_QW=30
//# Lexical states for SCLEX_VB, SCLEX_VBSCRIPT
lex VB=SCLEX_VB SCE_B_
lex VBScript=SCLEX_VBSCRIPT SCE_B_
public const int SCE_B_DEFAULT=0
public const int SCE_B_COMMENT=1
public const int SCE_B_NUMBER=2
public const int SCE_B_KEYWORD=3
public const int SCE_B_STRING=4
public const int SCE_B_PREPROCESSOR=5
public const int SCE_B_OPERATOR=6
public const int SCE_B_IDENTIFIER=7
public const int SCE_B_DATE=8
//# Lexical states for SCLEX_PROPERTIES
lex Properties=SCLEX_PROPERTIES SCE_PROPS_
public const int SCE_PROPS_DEFAULT=0
public const int SCE_PROPS_COMMENT=1
public const int SCE_PROPS_SECTION=2
public const int SCE_PROPS_ASSIGNMENT=3
public const int SCE_PROPS_DEFVAL=4
//# Lexical states for SCLEX_LATEX
lex LaTeX=SCLEX_LATEX SCE_L_
public const int SCE_L_DEFAULT=0
public const int SCE_L_COMMAND=1
public const int SCE_L_TAG=2
public const int SCE_L_MATH=3
public const int SCE_L_COMMENT=4
//# Lexical states for SCLEX_LUA
lex Lua=SCLEX_LUA SCE_LUA_
public const int SCE_LUA_DEFAULT=0
public const int SCE_LUA_COMMENT=1
public const int SCE_LUA_COMMENTLINE=2
public const int SCE_LUA_COMMENTDOC=3
public const int SCE_LUA_NUMBER=4
public const int SCE_LUA_WORD=5
public const int SCE_LUA_STRING=6
public const int SCE_LUA_CHARACTER=7
public const int SCE_LUA_LITERALSTRING=8
public const int SCE_LUA_PREPROCESSOR=9
public const int SCE_LUA_OPERATOR=10
public const int SCE_LUA_IDENTIFIER=11
public const int SCE_LUA_STRINGEOL=12
public const int SCE_LUA_WORD2=13
public const int SCE_LUA_WORD3=14
public const int SCE_LUA_WORD4=15
public const int SCE_LUA_WORD5=16
public const int SCE_LUA_WORD6=17
public const int SCE_LUA_WORD7=18
public const int SCE_LUA_WORD8=19
//# Lexical states for SCLEX_ERRORLIST
lex ErrorList=SCLEX_ERRORLIST SCE_ERR_
public const int SCE_ERR_DEFAULT=0
public const int SCE_ERR_PYTHON=1
public const int SCE_ERR_GCC=2
public const int SCE_ERR_MS=3
public const int SCE_ERR_CMD=4
public const int SCE_ERR_BORLAND=5
public const int SCE_ERR_PERL=6
public const int SCE_ERR_NET=7
public const int SCE_ERR_LUA=8
public const int SCE_ERR_CTAG=9
public const int SCE_ERR_DIFF_CHANGED=10
public const int SCE_ERR_DIFF_ADDITION=11
public const int SCE_ERR_DIFF_DELETION=12
public const int SCE_ERR_DIFF_MESSAGE=13
public const int SCE_ERR_PHP=14
public const int SCE_ERR_ELF=15
public const int SCE_ERR_IFC=16
//# Lexical states for SCLEX_BATCH
lex Batch=SCLEX_BATCH SCE_BAT_
public const int SCE_BAT_DEFAULT=0
public const int SCE_BAT_COMMENT=1
public const int SCE_BAT_WORD=2
public const int SCE_BAT_LABEL=3
public const int SCE_BAT_HIDE=4
public const int SCE_BAT_COMMAND=5
public const int SCE_BAT_IDENTIFIER=6
public const int SCE_BAT_OPERATOR=7
//# Lexical states for SCLEX_MAKEFILE
lex MakeFile=SCLEX_MAKEFILE SCE_MAKE_
public const int SCE_MAKE_DEFAULT=0
public const int SCE_MAKE_COMMENT=1
public const int SCE_MAKE_PREPROCESSOR=2
public const int SCE_MAKE_IDENTIFIER=3
public const int SCE_MAKE_OPERATOR=4
public const int SCE_MAKE_TARGET=5
public const int SCE_MAKE_IDEOL=9
//# Lexical states for SCLEX_DIFF
lex Diff=SCLEX_DIFF SCE_DIFF_
public const int SCE_DIFF_DEFAULT=0
public const int SCE_DIFF_COMMENT=1
public const int SCE_DIFF_COMMAND=2
public const int SCE_DIFF_HEADER=3
public const int SCE_DIFF_POSITION=4
public const int SCE_DIFF_DELETED=5
public const int SCE_DIFF_ADDED=6
//# Lexical states for SCLEX_CONF (Apache Configuration Files Lexer)
lex Conf=SCLEX_CONF SCE_CONF_
public const int SCE_CONF_DEFAULT=0
public const int SCE_CONF_COMMENT=1
public const int SCE_CONF_NUMBER=2
public const int SCE_CONF_IDENTIFIER=3
public const int SCE_CONF_EXTENSION=4
public const int SCE_CONF_PARAMETER=5
public const int SCE_CONF_STRING=6
public const int SCE_CONF_OPERATOR=7
public const int SCE_CONF_IP=8
public const int SCE_CONF_DIRECTIVE=9
//# Lexical states for SCLEX_AVE, Avenue
lex Avenue=SCLEX_AVE SCE_AVE_
public const int SCE_AVE_DEFAULT=0
public const int SCE_AVE_COMMENT=1
public const int SCE_AVE_NUMBER=2
public const int SCE_AVE_WORD=3
public const int SCE_AVE_STRING=6
public const int SCE_AVE_ENUM=7
public const int SCE_AVE_STRINGEOL=8
public const int SCE_AVE_IDENTIFIER=9
public const int SCE_AVE_OPERATOR=10
public const int SCE_AVE_WORD1=11
public const int SCE_AVE_WORD2=12
public const int SCE_AVE_WORD3=13
public const int SCE_AVE_WORD4=14
public const int SCE_AVE_WORD5=15
public const int SCE_AVE_WORD6=16
//# Lexical states for SCLEX_ADA
lex Ada=SCLEX_ADA SCE_ADA_
public const int SCE_ADA_DEFAULT=0
public const int SCE_ADA_WORD=1
public const int SCE_ADA_IDENTIFIER=2
public const int SCE_ADA_NUMBER=3
public const int SCE_ADA_DELIMITER=4
public const int SCE_ADA_CHARACTER=5
public const int SCE_ADA_CHARACTEREOL=6
public const int SCE_ADA_STRING=7
public const int SCE_ADA_STRINGEOL=8
public const int SCE_ADA_LABEL=9
public const int SCE_ADA_COMMENTLINE=10
public const int SCE_ADA_ILLEGAL=11
//# Lexical states for SCLEX_BAAN
lex Baan=SCLEX_BAAN SCE_BAAN_
public const int SCE_BAAN_DEFAULT=0
public const int SCE_BAAN_COMMENT=1
public const int SCE_BAAN_COMMENTDOC=2
public const int SCE_BAAN_NUMBER=3
public const int SCE_BAAN_WORD=4
public const int SCE_BAAN_STRING=5
public const int SCE_BAAN_PREPROCESSOR=6
public const int SCE_BAAN_OPERATOR=7
public const int SCE_BAAN_IDENTIFIER=8
public const int SCE_BAAN_STRINGEOL=9
public const int SCE_BAAN_WORD2=10
//# Lexical states for SCLEX_LISP
lex Lisp=SCLEX_LISP SCE_LISP_
public const int SCE_LISP_DEFAULT=0
public const int SCE_LISP_COMMENT=1
public const int SCE_LISP_NUMBER=2
public const int SCE_LISP_KEYWORD=3
public const int SCE_LISP_STRING=6
public const int SCE_LISP_STRINGEOL=8
public const int SCE_LISP_IDENTIFIER=9
public const int SCE_LISP_OPERATOR=10
//# Lexical states for SCLEX_EIFFEL and SCLEX_EIFFELKW
lex Eiffel=SCLEX_EIFFEL SCE_EIFFEL_
lex EiffelKW=SCLEX_EIFFELKW SCE_EIFFEL_
public const int SCE_EIFFEL_DEFAULT=0
public const int SCE_EIFFEL_COMMENTLINE=1
public const int SCE_EIFFEL_NUMBER=2
public const int SCE_EIFFEL_WORD=3
public const int SCE_EIFFEL_STRING=4
public const int SCE_EIFFEL_CHARACTER=5
public const int SCE_EIFFEL_OPERATOR=6
public const int SCE_EIFFEL_IDENTIFIER=7
public const int SCE_EIFFEL_STRINGEOL=8
//# Lexical states for SCLEX_NNCRONTAB (nnCron crontab Lexer)
lex NNCronTab=SCLEX_NNCRONTAB SCE_NNCRONTAB_
public const int SCE_NNCRONTAB_DEFAULT=0
public const int SCE_NNCRONTAB_COMMENT=1
public const int SCE_NNCRONTAB_TASK=2
public const int SCE_NNCRONTAB_SECTION=3
public const int SCE_NNCRONTAB_KEYWORD=4
public const int SCE_NNCRONTAB_MODIFIER=5
public const int SCE_NNCRONTAB_ASTERISK=6
public const int SCE_NNCRONTAB_NUMBER=7
public const int SCE_NNCRONTAB_STRING=8
public const int SCE_NNCRONTAB_ENVIRONMENT=9
public const int SCE_NNCRONTAB_IDENTIFIER=10
//# Lexical states for SCLEX_MATLAB
lex MatLab=SCLEX_MATLAB SCE_MATLAB_
public const int SCE_MATLAB_DEFAULT=0
public const int SCE_MATLAB_COMMENT=1
public const int SCE_MATLAB_COMMAND=2
public const int SCE_MATLAB_NUMBER=3
public const int SCE_MATLAB_KEYWORD=4
public const int SCE_MATLAB_STRING=5
public const int SCE_MATLAB_OPERATOR=6
public const int SCE_MATLAB_IDENTIFIER=7
//# Lexical states for SCLEX_SCRIPTOL
lex Sol=SCLEX_SCRIPTOL SCE_SCRIPTOL_
public const int SCE_SCRIPTOL_DEFAULT=0
public const int SCE_SCRIPTOL_WHITE=1
public const int SCE_SCRIPTOL_COMMENTLINE=2
public const int SCE_SCRIPTOL_PERSISTENT=3
public const int SCE_SCRIPTOL_CSTYLE=4
public const int SCE_SCRIPTOL_COMMENTBLOCK=5
public const int SCE_SCRIPTOL_NUMBER=6
public const int SCE_SCRIPTOL_STRING=7
public const int SCE_SCRIPTOL_CHARACTER=8
public const int SCE_SCRIPTOL_STRINGEOL=9
public const int SCE_SCRIPTOL_KEYWORD=10
public const int SCE_SCRIPTOL_OPERATOR=11
public const int SCE_SCRIPTOL_IDENTIFIER=12
public const int SCE_SCRIPTOL_TRIPLE=13
public const int SCE_SCRIPTOL_CLASSNAME=14
public const int SCE_SCRIPTOL_PREPROCESSOR=15
//# Lexical states for SCLEX_ASM
lex Asm=SCLEX_ASM SCE_ASM_
public const int SCE_ASM_DEFAULT=0
public const int SCE_ASM_COMMENT=1
public const int SCE_ASM_NUMBER=2
public const int SCE_ASM_STRING=3
public const int SCE_ASM_OPERATOR=4
public const int SCE_ASM_IDENTIFIER=5
public const int SCE_ASM_CPUINSTRUCTION=6
public const int SCE_ASM_MATHINSTRUCTION=7
public const int SCE_ASM_REGISTER=8
public const int SCE_ASM_DIRECTIVE=9
public const int SCE_ASM_DIRECTIVEOPERAND=10
//# Lexical states for SCLEX_FORTRAN
lex Fortran=SCLEX_FORTRAN SCE_F_
lex F77=SCLEX_F77 SCE_F_
public const int SCE_F_DEFAULT=0
public const int SCE_F_COMMENT=1
public const int SCE_F_NUMBER=2
public const int SCE_F_STRING1=3
public const int SCE_F_STRING2=4
public const int SCE_F_STRINGEOL=5
public const int SCE_F_OPERATOR=6
public const int SCE_F_IDENTIFIER=7
public const int SCE_F_WORD=8
public const int SCE_F_WORD2=9
public const int SCE_F_WORD3=10
public const int SCE_F_PREPROCESSOR=11
public const int SCE_F_OPERATOR2=12
public const int SCE_F_LABEL=13
public const int SCE_F_CONTINUATION=14
//# Lexical states for SCLEX_CSS
lex CSS=SCLEX_CSS SCE_CSS_
public const int SCE_CSS_DEFAULT=0
public const int SCE_CSS_TAG=1
public const int SCE_CSS_CLASS=2
public const int SCE_CSS_PSEUDOCLASS=3
public const int SCE_CSS_UNKNOWN_PSEUDOCLASS=4
public const int SCE_CSS_OPERATOR=5
public const int SCE_CSS_IDENTIFIER=6
public const int SCE_CSS_UNKNOWN_IDENTIFIER=7
public const int SCE_CSS_VALUE=8
public const int SCE_CSS_COMMENT=9
public const int SCE_CSS_ID=10
public const int SCE_CSS_IMPORTANT=11
public const int SCE_CSS_DIRECTIVE=12
public const int SCE_CSS_DOUBLESTRING=13
public const int SCE_CSS_SINGLESTRING=14
//# Lexical states for SCLEX_POV
lex POV=SCLEX_POV SCE_POV_
public const int SCE_POV_DEFAULT=0
public const int SCE_POV_COMMENT=1
public const int SCE_POV_COMMENTLINE=2
public const int SCE_POV_NUMBER=3
public const int SCE_POV_OPERATOR=4
public const int SCE_POV_IDENTIFIER=5
public const int SCE_POV_STRING=6
public const int SCE_POV_STRINGEOL=7
public const int SCE_POV_DIRECTIVE=8
public const int SCE_POV_BADDIRECTIVE=9
public const int SCE_POV_WORD2=10
public const int SCE_POV_WORD3=11
public const int SCE_POV_WORD4=12
public const int SCE_POV_WORD5=13
public const int SCE_POV_WORD6=14
public const int SCE_POV_WORD7=15
public const int SCE_POV_WORD8=16
//# Lexical states for SCLEX_LOUT
lex LOUT=SCLEX_LOUT SCE_LOUT_
public const int SCE_LOUT_DEFAULT=0
public const int SCE_LOUT_COMMENT=1
public const int SCE_LOUT_NUMBER=2
public const int SCE_LOUT_WORD=3
public const int SCE_LOUT_WORD2=4
public const int SCE_LOUT_WORD3=5
public const int SCE_LOUT_WORD4=6
public const int SCE_LOUT_STRING=7
public const int SCE_LOUT_OPERATOR=8
public const int SCE_LOUT_IDENTIFIER=9
public const int SCE_LOUT_STRINGEOL=10
//# Lexical states for SCLEX_ESCRIPT
lex ESCRIPT=SCLEX_ESCRIPT SCE_ESCRIPT_
public const int SCE_ESCRIPT_DEFAULT=0
public const int SCE_ESCRIPT_COMMENT=1
public const int SCE_ESCRIPT_COMMENTLINE=2
public const int SCE_ESCRIPT_COMMENTDOC=3
public const int SCE_ESCRIPT_NUMBER=4
public const int SCE_ESCRIPT_WORD=5
public const int SCE_ESCRIPT_STRING=6
public const int SCE_ESCRIPT_OPERATOR=7
public const int SCE_ESCRIPT_IDENTIFIER=8
public const int SCE_ESCRIPT_BRACE=9
public const int SCE_ESCRIPT_WORD2=10
public const int SCE_ESCRIPT_WORD3=11
//# Lexical states for SCLEX_PS
lex PS=SCLEX_PS SCE_PS_
public const int SCE_PS_DEFAULT=0
public const int SCE_PS_COMMENT=1
public const int SCE_PS_DSC_COMMENT=2
public const int SCE_PS_DSC_VALUE=3
public const int SCE_PS_NUMBER=4
public const int SCE_PS_NAME=5
public const int SCE_PS_KEYWORD=6
public const int SCE_PS_LITERAL=7
public const int SCE_PS_IMMEVAL=8
public const int SCE_PS_PAREN_ARRAY=9
public const int SCE_PS_PAREN_DICT=10
public const int SCE_PS_PAREN_PROC=11
public const int SCE_PS_TEXT=12
public const int SCE_PS_HEXSTRING=13
public const int SCE_PS_BASE85STRING=14
public const int SCE_PS_BADSTRINGCHAR=15
//# Lexical states for SCLEX_NSIS
lex NSIS=SCLEX_NSIS SCE_NSIS_
public const int SCE_NSIS_DEFAULT=0
public const int SCE_NSIS_COMMENT=1
public const int SCE_NSIS_STRINGDQ=2
public const int SCE_NSIS_STRINGLQ=3
public const int SCE_NSIS_STRINGRQ=4
public const int SCE_NSIS_FUNCTION=5
public const int SCE_NSIS_VARIABLE=6
public const int SCE_NSIS_LABEL=7
public const int SCE_NSIS_USERDEFINED=8
public const int SCE_NSIS_SECTIONDEF=9
public const int SCE_NSIS_SUBSECTIONDEF=10
public const int SCE_NSIS_IFDEFINEDEF=11
public const int SCE_NSIS_MACRODEF=12
public const int SCE_NSIS_STRINGVAR=13
//# Lexical states for SCLEX_MMIXAL
lex MMIXAL=SCLEX_MMIXAL SCE_MMIXAL_
public const int SCE_MMIXAL_LEADWS=0
public const int SCE_MMIXAL_COMMENT=1
public const int SCE_MMIXAL_LABEL=2
public const int SCE_MMIXAL_OPCODE=3
public const int SCE_MMIXAL_OPCODE_PRE=4
public const int SCE_MMIXAL_OPCODE_VALID=5
public const int SCE_MMIXAL_OPCODE_UNKNOWN=6
public const int SCE_MMIXAL_OPCODE_POST=7
public const int SCE_MMIXAL_OPERANDS=8
public const int SCE_MMIXAL_NUMBER=9
public const int SCE_MMIXAL_REF=10
public const int SCE_MMIXAL_CHAR=11
public const int SCE_MMIXAL_STRING=12
public const int SCE_MMIXAL_REGISTER=13
public const int SCE_MMIXAL_HEX=14
public const int SCE_MMIXAL_OPERATOR=15
public const int SCE_MMIXAL_SYMBOL=16
public const int SCE_MMIXAL_INCLUDE=17
//# Lexical states for SCLEX_CLW
lex Clarion=SCLEX_CLW SCE_CLW_
public const int SCE_CLW_DEFAULT=0
public const int SCE_CLW_LABEL=1
public const int SCE_CLW_COMMENT=2
public const int SCE_CLW_STRING=3
public const int SCE_CLW_USER_IDENTIFIER=4
public const int SCE_CLW_INTEGER_CONSTANT=5
public const int SCE_CLW_REAL_CONSTANT=6
public const int SCE_CLW_PICTURE_STRING=7
public const int SCE_CLW_KEYWORD=8
public const int SCE_CLW_COMPILER_DIRECTIVE=9
public const int SCE_CLW_BUILTIN_PROCEDURES_FUNCTION=10
public const int SCE_CLW_STRUCTURE_DATA_TYPE=11
public const int SCE_CLW_ATTRIBUTE=12
public const int SCE_CLW_STANDARD_EQUATE=13
public const int SCE_CLW_ERROR=14
//# Lexical states for SCLEX_LOT
lex LOT=SCLEX_LOT SCE_LOT_
public const int SCE_LOT_DEFAULT=0
public const int SCE_LOT_HEADER=1
public const int SCE_LOT_BREAK=2
public const int SCE_LOT_SET=3
public const int SCE_LOT_PASS=4
public const int SCE_LOT_FAIL=5
public const int SCE_LOT_ABORT=6
//# Lexical states for SCLEX_YAML
lex YAML=SCLEX_YAML SCE_YAML_
public const int SCE_YAML_DEFAULT=0
public const int SCE_YAML_COMMENT=1
public const int SCE_YAML_IDENTIFIER=2
public const int SCE_YAML_KEYWORD=3
public const int SCE_YAML_NUMBER=4
public const int SCE_YAML_REFERENCE=5
public const int SCE_YAML_DOCUMENT=6

//# Events

evt void StyleNeeded=2000(int position)
evt void CharAdded=2001(int ch)
evt void SavePointReached=2002()
evt void SavePointLeft=2003()
evt void ModifyAttemptRO=2004()
//# GTK+ Specific to work around focus and accelerator problems:
evt void Key=2005(int ch, int modifiers)
evt void DoubleClick=2006()
evt void UpdateUI=2007()
evt void Modified=2008(int position, int modificationType, string text, int length, int linesAdded, int line, int foldLevelNow, int foldLevelPrev)
evt void MacroRecord=2009(int message, int wParam, int lParam)
evt void MarginClick=2010(int modifiers, int position, int margin)
evt void NeedShown=2011(int position, int length)
evt void Painted=2013()
evt void UserListSelection=2014(int listType, string text)
evt void URIDropped=2015(string text)
evt void DwellStart=2016(int position)
evt void DwellEnd=2017(int position)
evt void Zoom=2018()
evt void HotSpotClick=2019(int modifiers, int position)
evt void HotSpotDoubleClick=2020(int modifiers, int position)
evt void CallTipClick=2021(int position)

//cat Deprecated

//# CARET_POLICY changed in 1.47
//fun void SetCaretPolicy=2369(int caretPolicy, int caretSlop)
public const int CARET_CENTER=0x02
public const int CARET_XEVEN=0x08
public const int CARET_XJUMPS=0x10

//# The old name for SCN_UPDATEUI
public const int SCN_CHECKBRACE=2007
evt void PosChanged=2012(int position)
